pub unsafe extern "C" fn decode(
drcontext: *mut c_void,
pc: *mut byte,
instr: *mut instr_t,
) -> *mut byteExpand description
Decodes the instruction at address \p pc into \p instr, filling in the instruction’s opcode, eflags usage, prefixes, and operands. The instruction’s raw bits are set to valid and pointed at \p pc (xref instr_get_raw_bits()). Assumes that \p instr is already initialized, but uses the x86/x64 mode for the thread \p dcontext rather than that set in instr. If caller is re-using same instr_t struct over multiple decodings, caller should call instr_reset() or instr_reuse(). Returns the address of the next byte after the decoded instruction. Returns NULL on decoding an invalid instr and sets opcode to OP_INVALID.