decode_memory_reference_size

Function decode_memory_reference_size 

pub unsafe extern "C" fn decode_memory_reference_size(
    drcontext: *mut c_void,
    pc: app_pc,
    size_in_bytes: *mut uint,
) -> app_pc
Calculates the size, in bytes, of the memory read or write of the instr at \p pc. If the instruction is a repeating string instruction, considers only one iteration. Returns the pc of the following instruction. If the instruction at \p pc does not reference memory, or is invalid, returns NULL.