decode_next_pc

Function decode_next_pc 

pub unsafe extern "C" fn decode_next_pc(
    drcontext: *mut c_void,
    pc: *mut byte,
) -> *mut byte
Decodes only enough of the instruction at address \p pc to determine its size. Returns the address of the byte following the instruction. May return NULL on decoding certain invalid instructions. / /** This corresponds to a Level 1 decoding. Levels are not exposed in the API anymore, however.