decode_trace

Function decode_trace 

pub unsafe extern "C" fn decode_trace(
    drcontext: *mut c_void,
    tag: *mut c_void,
) -> *mut instrlist_t
Decodes the trace with tag \p tag, and returns an instrlist_t of the instructions comprising that fragment. If \p tag is not a valid tag for an existing trace, the routine returns NULL. Clients can use dr_trace_exists_at() to determine whether the trace exists. \note Unlike the instruction list presented by the trace event, the list here does not include any existing client modifications. If client-modified instructions are needed, it is the responsibility of the client to record or recreate that list itself. \note This routine does not support decoding thread-private traces created by other than the calling thread.