disassemble_from_copy

Function disassemble_from_copy 

pub unsafe extern "C" fn disassemble_from_copy(
    drcontext: *mut c_void,
    copy_pc: *mut byte,
    orig_pc: *mut byte,
    outfile: file_t,
    show_pc: bool_,
    show_bytes: bool_,
) -> *mut byte
Decodes the instruction at address \p copy_pc as though it were located at address \p orig_pc, and then prints the instruction to file \p outfile. Prior to the instruction the address \p orig_pc is printed if \p show_pc and the raw bytes are printed if \p show_bytes. The default is to use DR’s custom syntax (see disassemble_set_syntax()). Returns the address of the subsequent instruction after the copy at \p copy_pc, or NULL if the instruction at \p copy_pc is invalid.