pub unsafe extern "C" fn disassemble_with_info(
drcontext: *mut c_void,
pc: *mut byte,
outfile: file_t,
show_pc: bool_,
show_bytes: bool_,
) -> *mut byteExpand description
Decodes and then prints the instruction at address \p pc to file \p outfile. Prior to the instruction the address is printed if \p show_pc and the raw bytes are printed if \p show_bytes. The default is to use DR’s custom syntax (see disassemble_set_syntax()). Returns the address of the subsequent instruction, or NULL if the instruction at \p pc is invalid.