dr_annotation_register_return

Function dr_annotation_register_return 

pub unsafe extern "C" fn dr_annotation_register_return(
    annotation_name: *const c_char,
    return_value: *mut c_void,
) -> bool_
Register a return value substitution for a DR annotation. When the annotation is encountered, it will be replaced with the specified return value. This function returns true on successful registration.

@param[in] annotation_name The name of the annotation function as it appears in the target app’s source code (unmangled). @param[in] return_value The value to return from every instance of the annotation.