dr_annotation_register_valgrind

Function dr_annotation_register_valgrind 

pub unsafe extern "C" fn dr_annotation_register_valgrind(
    request_id: dr_valgrind_request_id_t,
    annotation_callback: Option<unsafe extern "C" fn(request: *mut dr_vg_client_request_t) -> ptr_uint_t>,
) -> bool_
Register a callback for a Valgrind client request id. When the request is encountered, the specified callback will be invoked by an internal routing function. Returns true on successful registration.

@param[in] request_id The Valgrind request id for which to register. @param[in] annotation_callback The client function to call when an instance of the specified Valgrind client request is executed.