dr_annotation_unregister_call

Function dr_annotation_unregister_call 

pub unsafe extern "C" fn dr_annotation_unregister_call(
    annotation_name: *const c_char,
    callee: *mut c_void,
) -> bool_
Unregister the specified handler from a DR annotation. Instances of the annotation that have already been substituted with a clean call to the registered callee will remain in the code cache, but any newly encountered instances of the annotation will no longer be substituted with this callee. This function does nothing in the case that the specified callee was never registered for this annotation (or has already been unregistered). Returns true if the registration was successfully unregistered.

@param[in] annotation_name The annotation function for which to unregister. @param[in] callee The callee to unregister.