pub unsafe extern "C" fn dr_annotation_unregister_return(
annotation_name: *const c_char,
) -> bool_Expand description
Unregister the (universal) return value from a DR annotation. Instances of the annotation that have already been substituted with the return value will remain in the code cache, but any newly encountered instances of the annotation will no longer be substituted. This function does nothing in the case that no return value is currently registered for the specified annotation (or has already been unregistered). Note that if another client has registered a return value, this function will remove that other client’s registration. Returns true if the registration was successfully unregistered.
@param[in] annotation_name The annotation function for which to unregister.