dr_annotation_unregister_valgrind

Function dr_annotation_unregister_valgrind 

pub unsafe extern "C" fn dr_annotation_unregister_valgrind(
    request_id: dr_valgrind_request_id_t,
    annotation_callback: Option<unsafe extern "C" fn(request: *mut dr_vg_client_request_t) -> ptr_uint_t>,
) -> bool_
Unregister the specified callback from a Valgrind client request. The registered callback will not be invoked in association with this client request again (though if the same callback function is also registered for other Valgrind client requests, it will still be invoked in association with those client requests). This function does nothing in the case that no handler was ever registered for this callback function. Returns true if the registration was found and successfully unregistered.

@param[in] request_id The request id for which to unregister (DR_VG__*). @param[in] annotation_callback The callback function to unregister.