pub unsafe extern "C" fn dr_app_arg_as_cstring(
app_arg: *mut dr_app_arg_t,
buf: *mut c_char,
buf_size: c_int,
) -> *const c_charExpand description
Returns the passed argument \p app_arg as a string. \p buf is used only if needed, and therefore the caller should not assume that the string is in the \p buf. In other words, always use the returned value to refer to the string. Returns NULL on error such as when \p buf is needed as storage and the size of the buffer \p buf_size is not sufficient.
To obtain a suitable upper-bound size of the string buffer, get the size of the argument from the #dr_app_arg_t value retrieved via dr_get_app_args().
\note Currently, this function is only available on Unix with early injection.
\note An error code may be obtained via dr_get_error_code() when this routine fails.