dr_app_pc_as_jump_target

Function dr_app_pc_as_jump_target 

pub unsafe extern "C" fn dr_app_pc_as_jump_target(
    isa_mode: dr_isa_mode_t,
    pc: app_pc,
) -> app_pc
Given an application program counter value, returns the corresponding value to use as an indirect branch target for the given \p isa_mode. For ARM’s Thumb mode (#DR_ISA_ARM_THUMB), this involves setting the least significant bit of the address.