dr_app_pc_as_load_target

Function dr_app_pc_as_load_target 

pub unsafe extern "C" fn dr_app_pc_as_load_target(
    isa_mode: dr_isa_mode_t,
    pc: app_pc,
) -> app_pc
Given an application program counter value, returns the corresponding value to use as a memory load target for the given \p isa_mode, or for comparing to the application address inside a basic block or trace. For ARM’s Thumb mode (#DR_ISA_ARM_THUMB), this involves clearing the least significant bit of the address.