pub unsafe extern "C" fn dr_app_start()Expand description
Causes the application to run under DR control upon return from this call. Attempts to take over any existing threads in the application.
\warning On Linux, DR detects threads by listing thread ids in the current process’s thread group. This, and other queries about the current process may fail if the main thread has quit. DR also assumes the threads all share signal handlers, as is the case for pthreads. Violating these assumptions will lead to unpredictable behavior.