dr_app_stop

Function dr_app_stop 

pub unsafe extern "C" fn dr_app_stop()
Causes all of the application’s threads to run directly on the machine upon return from this call; no effect if the application is not currently running under DR control.