dr_app_stop_and_cleanup

Function dr_app_stop_and_cleanup 

pub unsafe extern "C" fn dr_app_stop_and_cleanup()
Causes all of the application’s threads to run directly on the machine upon return from this call, and additionally frees the resources used by DR. Once this is invoked, calling dr_app_start() is not supported until dr_app_setup() or dr_app_setup_and_start() is called for a re-attach.

This call has no effect if the application is not currently running under DR control.