dr_app_stop_and_cleanup_with_stats

Function dr_app_stop_and_cleanup_with_stats 

pub unsafe extern "C" fn dr_app_stop_and_cleanup_with_stats(
    drstats: *mut dr_stats_t,
)
Same as dr_app_stop_and_cleanup, additionally filling in the provided dr_stats_t object, after all threads have been detached and right before clearing stats. The parameter may be NULL, in which case stats are not collected, the API behaving identically to dr_app_stop_and_cleanup().