dr_get_app_PEB

Function dr_get_app_PEB 

pub unsafe extern "C" fn dr_get_app_PEB() -> *mut c_void
Returns a pointer to the application’s Process Environment Block (PEB). DR swaps to a private PEB when running client code, in order to isolate the client and its dependent libraries from the application, so conventional methods of reading the PEB will obtain the private PEB instead of the application PEB. \note Windows only.