dr_get_current_directory

Function dr_get_current_directory 

pub unsafe extern "C" fn dr_get_current_directory(
    buf: *mut c_char,
    bufsz: usize,
) -> bool_
Returns the current directory for this process in \p buf. On Windows, reading the current directory is considered unsafe except during initialization, as it is stored in user memory and access is not controlled via any standard synchronization.