dr_get_dr_thread_handle

Function dr_get_dr_thread_handle 

pub unsafe extern "C" fn dr_get_dr_thread_handle(
    drcontext: *mut c_void,
) -> HANDLE
Returns a Windows handle to the thread with drcontext \p drcontext. This handle is DR’s handle to this thread (it is not a separate copy) and as such it should not be closed by the caller; nor should it be used beyond the thread’s exit, as DR’s handle will be closed at that point.

The handle should have THREAD_ALL_ACCESS privileges. \note Windows only.