pub unsafe extern "C" fn dr_get_process_id_from_drcontext(
drcontext: *mut c_void,
) -> process_id_tExpand description
Returns the process id of the process associated with drcontext \p drcontext. The returned value may be different from dr_get_process_id() if the passed context was created in a different process, which may happen in thread exit callbacks.