pub unsafe extern "C" fn dr_get_thread_id(
drcontext: *mut c_void,
) -> thread_id_tExpand description
Returns the thread id of the thread with drcontext \p drcontext.
pub unsafe extern "C" fn dr_get_thread_id(
drcontext: *mut c_void,
) -> thread_id_tReturns the thread id of the thread with drcontext \p drcontext.