dr_hashtable_add

Function dr_hashtable_add 

pub unsafe extern "C" fn dr_hashtable_add(
    drcontext: *mut c_void,
    htable: *mut c_void,
    key: ptr_uint_t,
    payload: *mut c_void,
)
Adds a new entry to the hashtable.

@param[in] drcontext Must be the same context passed to dr_hashtable_create(). @param[in] htable A pointer to the table itself, returned by dr_hashtable_create(). @param[in] key The key to add. @param[in] payload The payload to add.