dr_insert_cbr_instrumentation

Function dr_insert_cbr_instrumentation 

pub unsafe extern "C" fn dr_insert_cbr_instrumentation(
    drcontext: *mut c_void,
    ilist: *mut instrlist_t,
    instr: *mut instr_t,
    callee: *mut c_void,
)
Assumes that \p instr is a conditional branch Inserts into \p ilist prior to \p instr instruction(s) to call callee passing three arguments: -# address of branch instruction -# target address of branch -# 0 if the branch is not taken, 1 if it is taken \note Sets #DR_CLEANCALL_READS_APP_CONTEXT and #DR_CLEANCALL_WRITES_APP_CONTEXT. Conditionally skipping the instrumentation inserted by this routine is not supported (i.e., #DR_CLEANCALL_MULTIPATH is not supported here).