pub unsafe extern "C" fn dr_insert_cbr_instrumentation_ex(
drcontext: *mut c_void,
ilist: *mut instrlist_t,
instr: *mut instr_t,
callee: *mut c_void,
user_data: opnd_t,
)Expand description
Assumes that \p instr is a conditional branch Inserts into \p ilist prior to \p instr instruction(s) to call callee passing four arguments: -# address of branch instruction -# target address of branch -# fall-through address of branch -# 0 if the branch is not taken, 1 if it is taken -# user defined operand (e.g., TLS slot, immed value, register, etc.) \note The user defined operand cannot use register ebx! \note Sets #DR_CLEANCALL_READS_APP_CONTEXT and #DR_CLEANCALL_WRITES_APP_CONTEXT. Conditionally skipping the instrumentation inserted by this routine is not supported (i.e., #DR_CLEANCALL_MULTIPATH is not supported here).