dr_is_nudge_thread

Function dr_is_nudge_thread 

pub unsafe extern "C" fn dr_is_nudge_thread(
    drcontext: *mut c_void,
) -> bool_
On Windows, nudges are implemented via remotely injected threads. This routine returns whether or not the thread indicated by \p drcontext is such a nudge thread. \note Windows only.