dr_load_aux_library

Function dr_load_aux_library 

pub unsafe extern "C" fn dr_load_aux_library(
    name: *const c_char,
    lib_start: *mut *mut byte,
    lib_end: *mut *mut byte,
) -> dr_auxlib_handle_t
Loads the library with the given path as an auxiliary client library. The library is not treated as an application module but as an extension of DR. The library will be included in dr_memory_is_in_client() and any faults in the library will be considered client faults. The bounds of the loaded library are returned in the optional out variables. On failure, returns NULL.

If only a filename and not a full path is given, this routine will search for the library in the standard search locations for DR’s private loader.