dr_lookup_aux_library_routine

Function dr_lookup_aux_library_routine 

pub unsafe extern "C" fn dr_lookup_aux_library_routine(
    lib: dr_auxlib_handle_t,
    name: *const c_char,
) -> dr_auxlib_routine_ptr_t
Looks up the exported routine with the given name in the given client auxiliary library loaded by dr_load_aux_library(). Returns NULL on failure.