pub unsafe extern "C" fn dr_memory_is_in_client(
pc: *const byte,
) -> bool_Expand description
Returns true iff pc is located inside a client library, an Extension library used by a client, or an auxiliary client library (see dr_load_aux_library()).