dr_merge_arith_flags

Function dr_merge_arith_flags 

pub unsafe extern "C" fn dr_merge_arith_flags(
    cur_xflags: reg_t,
    saved_xflag: reg_t,
) -> reg_t
A convenience routine to aid restoring the arith flags done by outlined code, such as when handling restore state events. The routine takes the current value of the flags register \p cur_xflags, as well as the saved value \p saved_xflag, in order to return the original app value.