dr_module_contains_addr

Function dr_module_contains_addr 

pub unsafe extern "C" fn dr_module_contains_addr(
    data: *const module_data_t,
    addr: app_pc,
) -> bool_
Returns whether \p addr is contained inside any segment of the module \p data. We recommend using this routine rather than checking against the \p start and \p end fields of \p data, as modules are not always contiguous.