pub unsafe extern "C" fn dr_module_preferred_name(
data: *const module_data_t,
) -> *const c_charExpand description
Returns the preferred name for the module described by \p data from \p data->module_names.
pub unsafe extern "C" fn dr_module_preferred_name(
data: *const module_data_t,
) -> *const c_charReturns the preferred name for the module described by \p data from \p data->module_names.