dr_module_set_should_instrument

Function dr_module_set_should_instrument 

pub unsafe extern "C" fn dr_module_set_should_instrument(
    handle: module_handle_t,
    should_instrument: bool_,
) -> bool_
Set whether or not the module referred to by \p handle should be instrumented. If \p should_instrument is false, code from the module will not be passed to the basic block event. If traces are enabled, code from the module will still reach the trace event. Must be called from the module load event for the module referred to by \p handle. \return whether successful.

\warning Turning off instrumentation for modules breaks clients and extensions, such as drwrap, that expect to see every instruction.