pub unsafe extern "C" fn dr_module_should_instrument(
handle: module_handle_t,
) -> bool_Expand description
Return whether code from the module should be instrumented, meaning passed to the basic block event.
pub unsafe extern "C" fn dr_module_should_instrument(
handle: module_handle_t,
) -> bool_Return whether code from the module should be instrumented, meaning passed to the basic block event.