dr_nudge_client

Function dr_nudge_client 

pub unsafe extern "C" fn dr_nudge_client(
    id: client_id_t,
    argument: uint64,
) -> bool_
Triggers an asynchronous nudge event in the current process. The callback function registered with dr_register_nudge_event() will be called with the supplied \p argument (in a new non-application thread on Windows).

\note On Linux, the nudge will not be delivered until this thread exits the code cache. Thus, if this routine is called from a clean call, dr_redirect_execution() should be used to ensure cache exit.