pub unsafe extern "C" fn dr_nudge_client_ex(
process_id: process_id_t,
client_id: client_id_t,
argument: uint64,
timeout_ms: uint,
) -> dr_config_status_tExpand description
Triggers an asynchronous nudge event in a target process. The callback function registered with dr_register_nudge_event() for the specified client in the specified process will be called with the supplied \p argument (in a new non-application thread on Windows).
\note On Linux, if \p pid is the current process, the nudge will not be delivered until this thread exits the code cache. Thus, if this routine is called from a clean call and \p pid is the current process, dr_redirect_execution() should be used to ensure cache exit.
\param[in] process_id The system id of the process to nudge (see dr_get_process_id())
\param[in] client_id The unique client ID provided at client registration.
\param[in] argument An argument passed to the client’s nudge handler.
\param[in] timeout_ms Windows only. The number of milliseconds to wait for each nudge to complete before continuing. If INFINITE is supplied then the wait is unbounded. If 0 is supplied the no wait is performed. If a non-0 wait times out DR_NUDGE_TIMEOUT will be returned.
\return A dr_config_status_t code indicating the result of the nudge.