pub unsafe extern "C" fn dr_nudge_pid(
process_id: process_id_t,
client_id: client_id_t,
arg: uint64,
timeout_ms: uint,
) -> dr_config_status_tExpand description
Provides a mechanism for an external entity on the guest OS to communicate with a client. Requires administrative privileges. A process ‘nudge’ causes a client event handler to be invoked (use dr_register_nudge_event() to register the handler function). A nudge is ignored if the process is not running under DynamoRIO, the specified client is not loaded, or if the client does not provide a handler.
\param[in] process_id The system id of the process to nudge (see dr_get_process_id())
\param[in] client_id The unique client ID provided at client registration.
\param[in] arg An argument passed to the client’s nudge handler.
\param[in] timeout_ms The number of milliseconds to wait for the nudge to complete before returning. If INFINITE is supplied then the wait is unbounded. If 0 is supplied the no wait is performed. If the wait times out DR_NUDGE_TIMEOUT will be returned.
\return A dr_config_status_t code indicating the result of the nudge.
\remarks A process nudge is a one way asynchronous communication from an external entity to a client. It does not allow a client to return information back to the nudge originator. To communicate from a client to another process, use the channels specified in \ref sec_comm.
\note Not yet available on MacOS.