pub unsafe extern "C" fn dr_persist_size( perscxt: *mut c_void, ) -> usize
Takes in the \p perscxt opaque parameter passed to various persistence events and returns the size of the code region being persisted.