dr_register_exit_event

Function dr_register_exit_event 

pub unsafe extern "C" fn dr_register_exit_event(
    func: Option<unsafe extern "C" fn()>,
)
Registers a callback function for the process exit event. DR calls \p func when the process exits. By default, the process exit event will be executed with only a single live thread. dr_set_process_exit_behavior() can provide superior exit performance for clients that have flexible exit event requirements.

On Linux, SYS_execve does NOT result in an exit event, but it WILL result in the client library being reloaded and its dr_client_main() routine being called.