dr_register_low_on_memory_event

Function dr_register_low_on_memory_event 

pub unsafe extern "C" fn dr_register_low_on_memory_event(
    func: Option<unsafe extern "C" fn()>,
)
Registers a callback function for the low on memory event. DR calls \p func whenever virtual memory is tight and enables the client to help free space.