dr_registered_process_iterator_start

Function dr_registered_process_iterator_start 

pub unsafe extern "C" fn dr_registered_process_iterator_start(
    dr_platform: dr_platform_t,
    global: bool_,
) -> *mut dr_registered_process_iterator_t
Creates and starts an iterator for iterating over all processes registered for the given platform and given global or local parameter.

\param[in] dr_platform Configurations are kept separate for 32-bit processes and 64-bit processes. This parameter allows selecting which of those configurations to check.

\param[in] global Whether to use global or user-local config files. On Windows, global config files are stored in a dir pointed at by the DYNAMORIO_HOME registry key. On Linux, they are in /etc/dynamorio. Administrative privileges may be needed if global is true. Note that DynamoRIO gives local config files precedence when both exist. The caller must separately create the global directory.

\return iterator for use with dr_registered_process_iterator_hasnext()and dr_registered_process_iterator_next(). Must be freed with dr_registered_process_iterator_stop()

\note Not yet available on Linux or MacOS.