pub unsafe extern "C" fn dr_remove_it_instrs(
drcontext: *mut c_void,
ilist: *mut instrlist_t,
) -> c_intExpand description
Removes all OP_it instructions from \p ilist without changing the instructions that were inside each IT block. This is intended to be paired with dr_insert_it_instrs(), where a client’s examination of the application instruction list and insertion of instrumentation occurs in between the two calls and thus does not have to worry about groups of instructions that cannot be separated or changed. The resulting predicated instructions are not encodable in Thumb mode (#DR_ISA_ARM_THUMB): dr_insert_it_instrs() must be called before encoding.
\return the number of OP_it instructions removed; -1 on error.
\note ARM-only