pub unsafe extern "C" fn dr_resume_all_other_threads(
drcontexts: *mut *mut c_void,
num_suspended: uint,
) -> bool_Expand description
May only be used after invoking dr_suspend_all_other_threads(). This routine resumes the threads that were suspended by dr_suspend_all_other_threads() and must be passed the same array and count of suspended threads that were returned by dr_suspend_all_other_threads(). It also frees the \p drcontexts array and releases the locks acquired by dr_suspend_all_other_threads(). The return value indicates whether all resumption attempts were successful.