pub unsafe extern "C" fn dr_rwlock_mark_as_app(
rwlock: *mut c_void,
) -> bool_Expand description
Instructs DR to treat this lock as an application lock. Primarily this avoids debug-build checks that no DR locks are held in situations where locks are disallowed.
\warning Any one lock should either be a DR lock or an application lock. Use this routine with caution and do not call it on a DR lock that is used in DR contexts, as it disables debug checks.
\return whether successful.