pub unsafe extern "C" fn dr_safe_read(
base: *const c_void,
size: usize,
out_buf: *mut c_void,
bytes_read: *mut usize,
) -> bool_Expand description
Safely reads \p size bytes from address \p base into buffer \p out_buf. Reading is done without the possibility of an exception occurring. Returns true if the entire \p size bytes were read; otherwise returns false and if \p bytes_read is non-NULL returns the partial number of bytes read in \p bytes_read. \note See also DR_TRY_EXCEPT().