dr_set_client_name

Function dr_set_client_name 

pub unsafe extern "C" fn dr_set_client_name(
    name: *const c_char,
    report_URL: *const c_char,
) -> bool_
Sets information presented to users in diagnostic messages. Only one name is supported, regardless of how many clients are in use. If this routine is called a second time, the new values supersede the original. The \p report_URL is meant to be a bug tracker location where users should go to report errors in the client end-user tool.