dr_set_tls_field

Function dr_set_tls_field 

pub unsafe extern "C" fn dr_set_tls_field(
    drcontext: *mut c_void,
    value: *mut c_void,
)
Sets the user-controlled thread-local-storage field. To generate an instruction sequence that reads the drcontext field inline in the code cache, use dr_insert_write_tls_field().