pub unsafe extern "C" fn dr_switch_to_app_state_ex(
drcontext: *mut c_void,
flags: dr_state_flags_t,
)Expand description
Swaps to the application version of any system state for the given thread. This is meant to be used prior to examining application memory, when private libraries are in use and there are two versions of system state. Invoking non-DR library routines while the application state is in place can lead to unpredictable results: call dr_switch_to_dr_state() (or the _ex version) before doing so.
This function does not affect whether the current machine context (registers) contains application state or not.
The \p flags argument allows selecting a subset of the state to swap.