pub unsafe extern "C" fn dr_symbol_export_iterator_hasnext(
iter: *mut dr_symbol_export_iterator_t,
) -> bool_Expand description
Returns true if there is another exported symbol in the iterator.
pub unsafe extern "C" fn dr_symbol_export_iterator_hasnext(
iter: *mut dr_symbol_export_iterator_t,
) -> bool_Returns true if there is another exported symbol in the iterator.