pub unsafe extern "C" fn dr_symbol_import_iterator_hasnext(
iter: *mut dr_symbol_import_iterator_t,
) -> bool_Expand description
Returns true if there is another imported symbol in the iterator.
pub unsafe extern "C" fn dr_symbol_import_iterator_hasnext(
iter: *mut dr_symbol_import_iterator_t,
) -> bool_Returns true if there is another imported symbol in the iterator.