dr_symbol_import_iterator_start

Function dr_symbol_import_iterator_start 

pub unsafe extern "C" fn dr_symbol_import_iterator_start(
    handle: module_handle_t,
    from_module: *mut dr_module_import_desc_t,
) -> *mut dr_symbol_import_iterator_t
Creates an iterator over symbols imported by a module. If \p from_module is NULL, all imported symbols are yielded, regardless of which module they were imported from.

On Windows, from_module is obtained from a \p dr_module_import_t and used to iterate over all of the imports from a specific module.

The iterator returned is invalid until after the first call to dr_symbol_import_iterator_next().

\note On Windows, symbols imported from delay-loaded DLLs are not included yet.