pub unsafe extern "C" fn dr_syscall_get_result(
drcontext: *mut c_void,
) -> reg_tExpand description
Usable only from a post-syscall (dr_register_post_syscall_event()) event. Returns the return value of the system call that will be presented to the application.
\note On some platforms (such as MacOS), a 32-bit application’s system call can return a 64-bit value. Use dr_syscall_get_result_ex() to obtain the upper bits in that case.
\note On some platforms (such as MacOS), whether a system call succeeded or failed cannot be determined from the main result value. Use dr_syscall_get_result_ex() to obtain the success result in such cases.