dr_track_where_am_i

Function dr_track_where_am_i 

pub unsafe extern "C" fn dr_track_where_am_i()
Should be called during process initialization. Requests more accurate tracking of the #dr_where_am_i_t value for use with dr_where_am_i(). By default, if this routine is not called, DR avoids some updates to the value that incur extra overhead, such as identifying clean callees.