pub unsafe extern "C" fn dr_unload_aux_library(
lib: dr_auxlib_handle_t,
) -> bool_Expand description
Unloads the given library, which must have been loaded by dr_load_aux_library(). Returns whether successful.
pub unsafe extern "C" fn dr_unload_aux_library(
lib: dr_auxlib_handle_t,
) -> bool_Unloads the given library, which must have been loaded by dr_load_aux_library(). Returns whether successful.