dr_unmap_file

Function dr_unmap_file 

pub unsafe extern "C" fn dr_unmap_file(
    map: *mut c_void,
    size: usize,
) -> bool_
Unmaps a portion of a file mapping previously created by dr_map_file(). \return whether successful.

@param[in] map The base address to be unmapped. Must be page size aligned. @param[in] size The size to be unmapped. All pages overlapping with the range are unmapped.

\note On Windows, the whole file will be unmapped instead.