pub unsafe extern "C" fn dr_unregister_low_on_memory_event(
func: Option<unsafe extern "C" fn()>,
) -> bool_Expand description
Unregister a callback function for low on memory events. \return true if unregistration is successful and false if it is not (e.g., the function was not registered).