pub unsafe extern "C" fn dr_unregister_persist_rx(
func_size: Option<unsafe extern "C" fn(drcontext: *mut c_void, perscxt: *mut c_void, file_offs: usize, user_data: *mut *mut c_void) -> usize>,
func_persist: Option<unsafe extern "C" fn(drcontext: *mut c_void, perscxt: *mut c_void, fd: file_t, user_data: *mut c_void) -> bool_>,
func_resurrect: Option<unsafe extern "C" fn(drcontext: *mut c_void, perscxt: *mut c_void, map: *mut *mut byte) -> bool_>,
) -> bool_Expand description
Unregister callback functions for storing executable code in a persisted cache file. \return true if unregistration is successful and false if it is not (e.g., one of the functions was not registered).