dr_unregister_trace_event

Function dr_unregister_trace_event 

pub unsafe extern "C" fn dr_unregister_trace_event(
    func: Option<unsafe extern "C" fn(drcontext: *mut c_void, tag: *mut c_void, trace: *mut instrlist_t, translating: bool_) -> dr_emit_flags_t>,
) -> bool_
Unregister a callback function for the trace event. \return true if unregistration is successful and false if it is not (e.g., \p func was not registered).

\note We do not recommend unregistering for the trace event unless it always returned #DR_EMIT_STORE_TRANSLATIONS, as doing so can prevent proper state translation on a later fault or other translation event. Instead of unregistering, turn the event callback into a nop.