pub unsafe extern "C" fn dr_using_console() -> bool_Expand description
Returns true if the current standard error handle belongs to a legacy console window (viz., \p cmd on Windows 7 or earlier). DR’s dr_printf() and dr_fprintf() do not work with such console windows unless dr_enable_console_printing() is called ahead of time, and even then there are limitations detailed in dr_enable_console_printing(). This routine may result in loading a private copy of kernel32.dll. \note Windows only.