dr_virtual_query

Function dr_virtual_query 

pub unsafe extern "C" fn dr_virtual_query(
    pc: *const byte,
    mbi: *mut MEMORY_BASIC_INFORMATION,
    mbi_size: usize,
) -> usize
Equivalent to the win32 API function VirtualQuery(). See that routine for a description of arguments and return values. \note Windows only.

\note DR may mark writable code pages as read-only but pretend they’re writable. When this happens, this routine will indicate that the memory is writable. Call dr_query_memory() or dr_query_memory_ex() before attempting to write to application memory to ensure it’s not read-only underneath.