pub unsafe extern "C" fn dr_where_am_i(
drcontext: *mut c_void,
pc: app_pc,
tag: *mut *mut c_void,
) -> dr_where_am_i_tExpand description
Returns the #dr_where_am_i_t value indicating in which area of code \p pc resides. This is meant for use with dr_set_itimer() for PC sampling for profiling purposes. If the optional \p tag is non-NULL and \p pc is inside a fragment in the code cache, the fragment’s tag is returned in \p tag. It is recommended that the user of this routine also call dr_track_where_am_i() during process initialization for more accurate results.