drmgr_get_cls_field

Function drmgr_get_cls_field 

pub unsafe extern "C" fn drmgr_get_cls_field(
    drcontext: *mut c_void,
    idx: c_int,
) -> *mut c_void
Returns the user-controlled callback-local-storage field for the given index, which was returned by drmgr_register_cls_field(). To generate an instruction sequence that reads the drcontext field inline in the code cache, use drmgr_insert_read_cls_field().