drmgr_get_parent_cls_field

Function drmgr_get_parent_cls_field 

pub unsafe extern "C" fn drmgr_get_parent_cls_field(
    drcontext: *mut c_void,
    idx: c_int,
) -> *mut c_void
Returns the user-controlled callback-local-storage field for the given index, which was returned by drmgr_register_cls_field(), for the parent context (i.e., the context most recently pushed either by a Windows callback entry or a call to drmgr_push_cls()). If there is no parent context, returns NULL.