pub unsafe extern "C" fn drmgr_get_tls_field(
drcontext: *mut c_void,
idx: c_int,
) -> *mut c_voidExpand description
Returns the user-controlled thread-local-storage field for the given index, which was returned by drmgr_register_tls_field(). To generate an instruction sequence that reads the drcontext field inline in the code cache, use drmgr_insert_read_tls_field().