drmgr_init

Function drmgr_init 

pub unsafe extern "C" fn drmgr_init() -> bool_
Initializes the drmgr extension. Must be called prior to any of the other routines. Can be called multiple times (by separate components, normally) but each call must be paired with a corresponding call to drmgr_exit().

\return whether successful.