pub unsafe extern "C" fn drmgr_insert_emulation_end(
drcontext: *mut c_void,
ilist: *mut instrlist_t,
where_: *mut instr_t,
)Expand description
Inserts a label into \p ilist prior to \p where to indicate the end of a sequence of instructions emulating an instruction, preceded by a label created with drmgr_insert_emulation_start(). Alternatively, #DR_EMULATE_REST_OF_BLOCK can be used on the start label to include the entire block, with no need for an end label.