drmgr_is_emulation_end

Function drmgr_is_emulation_end 

pub unsafe extern "C" fn drmgr_is_emulation_end(
    instr: *mut instr_t,
) -> bool_
Checks the instruction \p instr to see if it is an emulation end label created by drmgr_insert_emulation_end(). Typically used in an instrumentation client running with an emulation client.

\return true if \p instr is an emulation end label, false otherwise.