drmgr_is_emulation_start

Function drmgr_is_emulation_start 

pub unsafe extern "C" fn drmgr_is_emulation_start(
    instr: *mut instr_t,
) -> bool_
Checks the instruction \p instr to see if it is an emulation start label created by drmgr_insert_emulation_start(). Typically used in an instrumentation client running with an emulation client.

\return true if \p instr is an emulation start label, false otherwise.