drmgr_orig_app_instr_for_fetch

Function drmgr_orig_app_instr_for_fetch 

pub unsafe extern "C" fn drmgr_orig_app_instr_for_fetch(
    drcontext: *mut c_void,
) -> *mut instr_t
Must be called during drmgr’s insertion phase.

Returns the instruction to consider as the current application instruction for observational clients with respect to which instruction is executed, taking into account emulation. This may be different from the current instruction list instruction passed to the insertion event.

Returns NULL if observational clients should skip the current instruction list instruction.