drmgr_orig_app_instr_for_operands

Function drmgr_orig_app_instr_for_operands 

pub unsafe extern "C" fn drmgr_orig_app_instr_for_operands(
    drcontext: *mut c_void,
) -> *mut instr_t
Must be called during drmgr’s insertion phase.

Returns the instruction to consider as the current application instruction for observational clients with respect to the operands of the instruction, taking into account emulation. This may be different from the current instruction list instruction passed to the insertion event.

Returns NULL if observational clients should skip the current instruction list instruction.