pub unsafe extern "C" fn drmgr_register_bb_instru2instru_event(
func: drmgr_xform_cb_t,
priority: *mut drmgr_priority_t,
) -> bool_Expand description
Registers a callback function for the fourth instrumentation stage: instrumentation-to-instrumentation transformations on each basic block. drmgr will call \p func as the fourth of five instrumentation stages for each dynamic application basic block. Instrumentation-to-instrumentation passes are allowed to insert meta instructions but not non-meta instructions, and are intended for optimization of prior instrumentation passes.
All instrumentation must follow the guidelines for #dr_register_bb_event().
\return false if the given priority request cannot be satisfied (e.g., \p priority->before is already ordered after \p priority->after) or the given name is already taken.
@param[in] func The callback to be called. @param[in] priority Specifies the relative ordering of the callback. Can be NULL, in which case a default priority is used.