drmgr_register_bb_instrumentation_all_events

Function drmgr_register_bb_instrumentation_all_events 

pub unsafe extern "C" fn drmgr_register_bb_instrumentation_all_events(
    events: *mut drmgr_instru_events_t,
    priority: *mut drmgr_priority_t,
) -> bool_
Registers callbacks for all five instrumentation passes at once, with a \p user_data parameter passed among them all, enabling data sharing for all five of them. See the documentation for drmgr_register_bb_app2app_event(), drmgr_register_bb_instrumentation_event(), drmgr_register_bb_instru2instru_event(), and drmgr_register_bb_meta_instru_event() for further details of each pass. The aforementioned routines are identical to this with the exception of the extra \p user_data parameter, which is an OUT parameter to the \p app2app_func and passed in to the four subsequent callbacks. The \p priority param can be NULL, in which case a default priority is used.