drmgr_register_bb_instrumentation_ex_event

Function drmgr_register_bb_instrumentation_ex_event 

pub unsafe extern "C" fn drmgr_register_bb_instrumentation_ex_event(
    app2app_func: drmgr_app2app_ex_cb_t,
    analysis_func: drmgr_ilist_ex_cb_t,
    insertion_func: drmgr_insertion_cb_t,
    instru2instru_func: drmgr_ilist_ex_cb_t,
    priority: *mut drmgr_priority_t,
) -> bool_
Registers callbacks for the first four instrumentation passes at once, with a \p user_data parameter passed among them all, enabling data sharing for all four of them. See the documentation for drmgr_register_bb_app2app_event(), drmgr_register_bb_instrumentation_event(), and drmgr_register_bb_instru2instru_event() for further details of each pass. The aforementioned routines are identical to this with the exception of the extra \p user_data parameter, which is an OUT parameter to the \p app2app_func and passed in to the three subsequent callbacks. The \p priority param can be NULL, in which case a default priority is used.