drmgr_register_exception_event_ex

Function drmgr_register_exception_event_ex 

pub unsafe extern "C" fn drmgr_register_exception_event_ex(
    func: Option<unsafe extern "C" fn(drcontext: *mut c_void, excpt: *mut dr_exception_t) -> bool_>,
    priority: *mut drmgr_priority_t,
) -> bool_
Registers a callback function for the exception event, which behaves just like DR’s exception event dr_register_exception_event(), except that it is ordered according to \p priority. A default priority of 0 is used for events registered via drmgr_register_exception_event(). Just like for DR, the first callback to return false will short-circuit event delivery to later callbacks. \return whether successful.