pub unsafe extern "C" fn drmgr_register_module_load_event_user_data(
func: Option<unsafe extern "C" fn(drcontext: *mut c_void, info: *const module_data_t, loaded: bool_, user_data: *mut c_void)>,
priority: *mut drmgr_priority_t,
user_data: *mut c_void,
) -> bool_Expand description
Registers a callback function for the module load event, which behaves just like DR’s module load event dr_register_module_load_event(). Allows for the passing of user input \p user_data, which is available upon the execution of the callback. \return whether successful.
See also drmgr_register_module_load_event_ex().