pub unsafe extern "C" fn drmgr_register_thread_exit_event_user_data(
func: Option<unsafe extern "C" fn(drcontext: *mut c_void, user_data: *mut c_void)>,
priority: *mut drmgr_priority_t,
user_data: *mut c_void,
) -> bool_Expand description
Registers a callback function for the thread exit event, ordered by \p priority. Allows for the passing of user data \p user_data which is available upon the execution of the callback. drmgr calls \p func when an application thread exits. \return whether successful.
See also drmgr_register_thread_exit_event_ex().