pub unsafe extern "C" fn drmgr_register_thread_init_event_ex(
func: Option<unsafe extern "C" fn(drcontext: *mut c_void)>,
priority: *mut drmgr_priority_t,
) -> bool_Expand description
Registers a callback function for the thread initialization event, ordered by \p priority. drmgr calls \p func whenever the application creates a new thread. \return whether successful.