drmgr_register_thread_init_event_user_data

Function drmgr_register_thread_init_event_user_data 

pub unsafe extern "C" fn drmgr_register_thread_init_event_user_data(
    func: Option<unsafe extern "C" fn(drcontext: *mut c_void, user_data: *mut c_void)>,
    priority: *mut drmgr_priority_t,
    user_data: *mut c_void,
) -> bool_
Registers a callback function for the thread initialization event, ordered by \p priority. Allows for the passing of user data \p user_data which is available upon the execution of the callback. drmgr calls \p func whenever the application creates a new thread. \return whether successful.

See also drmgr_register_thread_init_event_ex().