drmgr_reserve_note_range

Function drmgr_reserve_note_range 

pub unsafe extern "C" fn drmgr_reserve_note_range(
    size: usize,
) -> ptr_uint_t
Reserves \p size values in the namespace for use in the \p note field of instructions. The reserved range starts at the return value and is contiguous. Returns DRMGR_NOTE_NONE on failure. Un-reserving is not supported.