drmgr_set_tls_field

Function drmgr_set_tls_field 

pub unsafe extern "C" fn drmgr_set_tls_field(
    drcontext: *mut c_void,
    idx: c_int,
    value: *mut c_void,
) -> bool_
Sets the user-controlled thread-local-storage field for the given index, which was returned by drmgr_register_tls_field(). To generate an instruction sequence that writes the drcontext field inline in the code cache, use drmgr_insert_write_tls_field(). \return whether successful.