drmgr_unregister_bb_insertion_event

Function drmgr_unregister_bb_insertion_event 

pub unsafe extern "C" fn drmgr_unregister_bb_insertion_event(
    func: drmgr_insertion_cb_t,
) -> bool_
Unregisters \p func from the second and third instrumentation stages. If an analysis callback was passed to drmgr_register_bb_instrumentation_event(), use drmgr_unregister_bb_instrumentation_event() instead.

\return true if unregistration is successful and false if it is not (e.g., \p func was not registered).

The recommendations for dr_unregister_bb_event() about when it is safe to unregister apply here as well.