drmgr_unregister_bb_instrumentation_all_events

Function drmgr_unregister_bb_instrumentation_all_events 

pub unsafe extern "C" fn drmgr_unregister_bb_instrumentation_all_events(
    events: *mut drmgr_instru_events_t,
) -> bool_
Unregisters the callbacks that were registered via drmgr_register_bb_instrumentation_all_events(). \return true if unregistration is successful and false if it is not (e.g., \p func was not registered).

The recommendations for dr_unregister_bb_event() about when it is safe to unregister apply here as well.