pub unsafe extern "C" fn drmgr_unregister_bb_meta_instru_event(
func: drmgr_xform_cb_t,
) -> bool_Expand description
Unregisters a callback function for the fifth instrumentation stage. \return true if unregistration is successful and false if it is not (e.g., \p func was not registered).
The recommendations for dr_unregister_bb_event() about when it is safe to unregister apply here as well.