pub unsafe extern "C" fn drmgr_unregister_module_load_event_user_data(
func: Option<unsafe extern "C" fn(drcontext: *mut c_void, info: *const module_data_t, loaded: bool_, user_data: *mut c_void)>,
) -> bool_Expand description
Unregister a callback function, which takes user data as a parameter for the module load event. \return true if unregistration is successful and false if it is not (e.g., \p func was not registered).
See also drmgr_unregister_module_load_event().