drmgr_unregister_module_unload_event

Function drmgr_unregister_module_unload_event 

pub unsafe extern "C" fn drmgr_unregister_module_unload_event(
    func: Option<unsafe extern "C" fn(drcontext: *mut c_void, info: *const module_data_t)>,
) -> bool_
Unregister a callback function for the module unload event. \return true if unregistration is successful and false if it is not (e.g., \p func was not registered).