pub unsafe extern "C" fn drmgr_unregister_post_syscall_event_user_data(
func: Option<unsafe extern "C" fn(drcontext: *mut c_void, sysnum: c_int, user_data: *mut c_void)>,
) -> bool_Expand description
Unregister a callback function, which takes user data, for the post-syscall event. \return true if unregistration is successful and false if it is not (e.g., \p func was not registered).
See also drmgr_unregister_post_syscall_event().