drmgr_unregister_pre_syscall_event_user_data

Function drmgr_unregister_pre_syscall_event_user_data 

pub unsafe extern "C" fn drmgr_unregister_pre_syscall_event_user_data(
    func: Option<unsafe extern "C" fn(drcontext: *mut c_void, sysnum: c_int, user_data: *mut c_void) -> bool_>,
) -> bool_
Unregister a callback function, which takes user data, for the pre-syscall event. \return true if unregistration is successful and false if it is not (e.g., \p func was not registered).

See also drmgr_unregister_pre_syscall_event().