drmgr_unregister_restore_state_event

Function drmgr_unregister_restore_state_event 

pub unsafe extern "C" fn drmgr_unregister_restore_state_event(
    func: Option<unsafe extern "C" fn(drcontext: *mut c_void, tag: *mut c_void, mcontext: *mut dr_mcontext_t, restore_memory: bool_, app_code_consistent: bool_)>,
) -> bool_
Unregister a callback function for the restore state event. \return true if unregistration is successful and false if it is not (e.g., \p func was not registered).