drmgr_unregister_restore_state_ex_event

Function drmgr_unregister_restore_state_ex_event 

pub unsafe extern "C" fn drmgr_unregister_restore_state_ex_event(
    func: Option<unsafe extern "C" fn(drcontext: *mut c_void, restore_memory: bool_, info: *mut dr_restore_state_info_t) -> bool_>,
) -> bool_
Unregister a callback function for the restore state extended event. \return true if unregistration is successful and false if it is not (e.g., \p func was not registered).