pub unsafe extern "C" fn drmgr_unregister_thread_exit_event_user_data(
func: Option<unsafe extern "C" fn(drcontext: *mut c_void, user_data: *mut c_void)>,
) -> bool_Expand description
Unregister a callback function for the thread exit event which also has user data passed to the callback. \return true if unregistration is successful and false if it is not (e.g., \p func was not registered).
See also drmgr_unregister_thread_exit_event().