drreg_are_aflags_dead

Function drreg_are_aflags_dead 

pub unsafe extern "C" fn drreg_are_aflags_dead(
    drcontext: *mut c_void,
    inst: *mut instr_t,
    dead: *mut bool_,
) -> drreg_status_t
Returns in \p dead whether the arithmetic flags are all dead at the point of \p inst. If called during drmgr’s insertion phase, \p inst must be the current application instruction.

@return whether successful or an error code on failure.