pub unsafe extern "C" fn drreg_exit() -> drreg_status_tExpand description
Cleans up the drreg extension. @return whether successful or an error code on failure.
pub unsafe extern "C" fn drreg_exit() -> drreg_status_tCleans up the drreg extension. @return whether successful or an error code on failure.