drreg_init_and_fill_vector

Function drreg_init_and_fill_vector 

pub unsafe extern "C" fn drreg_init_and_fill_vector(
    vec: *mut drvector_t,
    allowed: bool_,
) -> drreg_status_t
Initializes \p vec to hold #DR_NUM_GPR_REGS entries, each either set to NULL if \p allowed is false or a non-NULL value if \p allowed is true. This is intendend as a convenience routine for setting up the \p reg_allowed parameter to drreg_reserve_register().

@return whether successful or an error code on failure.