drreg_is_instr_spill_or_restore

Function drreg_is_instr_spill_or_restore 

pub unsafe extern "C" fn drreg_is_instr_spill_or_restore(
    drcontext: *mut c_void,
    instr: *mut instr_t,
    spill: *mut bool_,
    restore: *mut bool_,
    reg_spilled: *mut reg_id_t,
) -> drreg_status_t
Analyzes \p instr and returns whether it is a drreg register spill in \p spill, a drreg register restore in \p restore, and which register is being spilled or restored in \p reg_spilled. Each output parameter is optional and may be NULL. If DR’s spill slots are being used (see drreg_options_t.num_spill_slots), this routine may not be able to distinguish a drreg spill or restore from some other spill or restore.

@return whether successful or an error code on failure.