drreg_max_slots_used

Function drreg_max_slots_used 

pub unsafe extern "C" fn drreg_max_slots_used(
    max: *mut uint,
) -> drreg_status_t
In debug build, drreg tracks the maximum simultaneous number of spill slots in use. This can help a user to tune drreg_options_t.num_spill_slots.

@param[out] max The maximum number of spill slots used is written here. @return whether successful or an error code on failure. In release build, this routine always fails.