drreg_reservation_info_ex

Function drreg_reservation_info_ex 

pub unsafe extern "C" fn drreg_reservation_info_ex(
    drcontext: *mut c_void,
    reg: reg_id_t,
    info: *mut drreg_reserve_info_t,
) -> drreg_status_t
Returns information about the reservation and restoration status of \p reg. The \p size field of \p info must be set before calling. To query information about the arithmetic flags, pass #DR_REG_NULL for \p reg.

@return whether successful or an error code on failure.