pub unsafe extern "C" fn drreg_reserve_aflags(
drcontext: *mut c_void,
ilist: *mut instrlist_t,
where_: *mut instr_t,
) -> drreg_status_tExpand description
Requests exclusive use of the arithmetic flags register. Spills the application value at \p where in \p ilist, if necessary. When used during drmgr’s insertion phase, optimizations such as keeping the application flags value in a register and eliding duplicate spills and restores will be automatically applied. If called during drmgr’s insertion phase, \p where must be the current application instruction.
TODO i#3823: Support multi-phase use. This will require adding support to spill aflags to slots other than AFLAGS_SLOT.
@return whether successful or an error code on failure.