pub unsafe extern "C" fn drreg_reserve_dead_register(
drcontext: *mut c_void,
ilist: *mut instrlist_t,
where_: *mut instr_t,
reg_allowed: *mut drvector_t,
reg: *mut reg_id_t,
) -> drreg_status_tExpand description
Identical to drreg_reserve_register() except returns failure if no register is available that does not require a spill.
@return whether successful or an error code on failure.