drreg_set_bb_properties

Function drreg_set_bb_properties 

pub unsafe extern "C" fn drreg_set_bb_properties(
    drcontext: *mut c_void,
    flags: drreg_bb_properties_t,
) -> drreg_status_t
May only be called during drmgr’s app2app, analysis, or insertion phase. Sets the given properties for the current basic block being instrumented.

@return whether successful or an error code on failure.