drreg_statelessly_restore_all

Function drreg_statelessly_restore_all 

pub unsafe extern "C" fn drreg_statelessly_restore_all(
    drcontext: *mut c_void,
    ilist: *mut instrlist_t,
    where_restore: *mut instr_t,
    where_respill: *mut instr_t,
    restore_needed: *mut bool_,
    respill_needed: *mut bool_,
) -> drreg_status_t
Invokes drreg_statelessly_restore_app_value() for the arithmetic flags and every general-purpose register. Returns the logical OR of the ‘restore_needed’ and ‘respill_needed’ results from all of the drreg_statelessly_restore_app_value() calls. If any step results in an error, that error is returned and the output parameters are not filled in (despite partial restores potentially remaining in place).