drutil_init

Function drutil_init 

pub unsafe extern "C" fn drutil_init() -> bool_
Initializes the drutil extension. Must be called prior to any of the other routines. Can be called multiple times (by separate components, normally) but each call must be paired with a corresponding call to drutil_exit().

\return whether successful.