drvector_append

Function drvector_append 

pub unsafe extern "C" fn drvector_append(
    vec: *mut drvector_t,
    data: *mut c_void,
) -> bool_
Adds a new entry to the end of the vector, resizing it if necessary. If drvector_set_entry() has been called, this will add to the index beyond the last index passed to drvector_set_entry().