pub unsafe extern "C" fn drwrap_get_mcontext_ex(
wrapcxt: *mut c_void,
flags: dr_mcontext_flags_t,
) -> *mut dr_mcontext_tExpand description
Identical to drwrap_get_mcontext() but only fills in the state indicated by \p flags.
pub unsafe extern "C" fn drwrap_get_mcontext_ex(
wrapcxt: *mut c_void,
flags: dr_mcontext_flags_t,
) -> *mut dr_mcontext_tIdentical to drwrap_get_mcontext() but only fills in the state indicated by \p flags.