drwrap_get_retaddr

Function drwrap_get_retaddr 

pub unsafe extern "C" fn drwrap_get_retaddr(
    wrapcxt: *mut c_void,
) -> app_pc
Returns the return address of the wrapped function represented by \p wrapcxt.

This routine may de-reference application memory directly, so the caller should wrap in DR_TRY_EXCEPT if crashes must be avoided.