drwrap_mark_as_post_call

Function drwrap_mark_as_post_call 

pub unsafe extern "C" fn drwrap_mark_as_post_call(pc: app_pc) -> bool_
Records the address \p pc as a post-call address for instrumentation for post-call function wrapping purposes.

\note Only call this when the code leading up to \p pc is legitimate, as that code will be stored for consistency purposes and the post-call entry will be invalidated if it changes. This means that when using this routine for the performance purposes described in the drwrap_register_post_call_notify() documentation, the tool should wait for a newly loaded module to be relocated before calling this routine. A good approach is to wait for the first execution of code from the new module.

\return whether successful.