pub unsafe extern "C" fn drwrap_set_arg(
wrapcxt: *mut c_void,
arg: c_int,
val: *mut c_void,
) -> bool_Expand description
Sets the the \p arg-th argument (0-based) to the wrapped function represented by \p wrapcxt to \p val. Uses the calling convention set by drwrap_wrap_ex(), or for drwrap_wrap() assumes the regular C calling convention. May only be called from a \p drwrap_wrap pre-function callback. To access argument values in a post-function callback, store them in the \p user_data parameter passed between the pre and post functions.
This routine may write to application memory directly, so the caller should wrap in DR_TRY_EXCEPT if crashes must be avoided. \return whether successful.