pub unsafe extern "C" fn drwrap_set_global_flags(
flags: drwrap_global_flags_t,
) -> bool_Expand description
Sets flags that affect the global behavior of the drwrap module. This adds the passed-in \p flags to the current set of flags; it does not remove flags. This can be called at any time and it will affect future behavior. \return whether the flags were changed.