drwrap_set_mcontext

Function drwrap_set_mcontext 

pub unsafe extern "C" fn drwrap_set_mcontext(
    wrapcxt: *mut c_void,
) -> bool_
Propagates any changes made to the dr_mcontext_t pointed by drwrap_get_mcontext() back to the application.

\note if the #DRWRAP_FAST_CLEANCALLS flag is set, caller-saved register values in the fields controlled by #DR_MC_MULTIMEDIA will not contain valid values, but this should be fine because their values were scratch according to the ABI at the wrap point..