instr_allocate_raw_bits

Function instr_allocate_raw_bits 

pub unsafe extern "C" fn instr_allocate_raw_bits(
    drcontext: *mut c_void,
    instr: *mut instr_t,
    num_bytes: uint,
)
Allocates \p num_bytes of memory for \p instr’s raw bits. If \p instr currently points to raw bits, the allocated memory is initialized with the bytes pointed to. \p instr is then set to point to the allocated memory.