pub unsafe extern "C" fn instr_convert_short_meta_jmp_to_long(
drcontext: *mut c_void,
ilist: *mut instrlist_t,
instr: *mut instr_t,
) -> *mut instr_tExpand description
Assumes that instr is a meta instruction (instr_is_meta()) and an instr_is_cti_short() (<=8-bit reach). Converts instr’s opcode to a long form (32-bit reach for x86). If instr’s opcode is OP_loop* or OP_jecxz for x86 or OP_cbnz or OP_cbz for ARM, converts it to a sequence of multiple instructions (which is different from instr_is_cti_short_rewrite()). Each added instruction is marked instr_is_meta(). Returns the long form of the instruction, which is identical to \p instr unless \p instr is OP_{loop*,jecxz,cbnz,cbz}, in which case the return value is the final instruction in the sequence, the one that has long reach. \note DR automatically converts app short ctis to long form.