pub unsafe extern "C" fn instr_create_Ndst_Msrc_vardst(
drcontext: *mut c_void,
opcode: c_int,
fixed_dsts: uint,
fixed_srcs: uint,
var_dsts: uint,
var_ord: uint,
...
) -> *mut instr_tExpand description
Convenience routine that returns an initialized instr_t allocated on the thread-local heap with opcode \p opcode, \p fixed_dsts plus \p var_dsts destination operands, and \p fixed_srcs source operands. The variable arguments must start with the fixed destinations, followed by the (fixed) sources, followed by the variable destinations. The \p var_ord parameter specifies the (0-based) ordinal position within the resulting instruction’s destination array at which the variable destinations should be placed, allowing them to be inserted in the middle of the fixed destinations.