instr_disassemble

Function instr_disassemble 

pub unsafe extern "C" fn instr_disassemble(
    drcontext: *mut c_void,
    instr: *mut instr_t,
    outfile: file_t,
)
Prints the instruction \p instr to file \p outfile. Does not print address-size or data-size prefixes for other than just-decoded instrs, and does not check that the instruction has a valid encoding. Prints each operand with leading zeros indicating the size. The default is to use DR’s custom syntax (see disassemble_set_syntax()).