pub unsafe extern "C" fn instr_get_isa_mode(
instr: *mut instr_t,
) -> dr_isa_mode_tExpand description
Each instruction stores the processor mode under which it should be interpreted. This routine returns the mode for \p instr.
pub unsafe extern "C" fn instr_get_isa_mode(
instr: *mut instr_t,
) -> dr_isa_mode_tEach instruction stores the processor mode under which it should be interpreted. This routine returns the mode for \p instr.