instr_get_next_app

Function instr_get_next_app 

pub unsafe extern "C" fn instr_get_next_app(
    instr: *mut instr_t,
) -> *mut instr_t
Returns the next application (non-meta) instruction in the instruction list that contains \p instr.

\note As opposed to instr_get_next(), this routine skips all meta instructions inserted by either DynamoRIO or its clients.

\note We recommend using this routine during the phase of application code analysis, as any meta instructions present are guaranteed to be ok to skip. However, caution should be exercised if using this routine after any instrumentation insertion has already happened, as instrumentation might affect register usage or other factors being analyzed.