pub unsafe extern "C" fn instr_get_predicate(
instr: *mut instr_t,
) -> dr_pred_type_tExpand description
Returns the DR_PRED_ constant for \p instr that describes what its conditional execution is dependent on.
pub unsafe extern "C" fn instr_get_predicate(
instr: *mut instr_t,
) -> dr_pred_type_tReturns the DR_PRED_ constant for \p instr that describes what its conditional execution is dependent on.