pub unsafe extern "C" fn instr_has_encoding_hint(
instr: *mut instr_t,
hint: dr_encoding_hint_type_t,
) -> bool_Expand description
Each instruction may store a hint for how the instruction should be encoded if redundant encodings are available. This presumes that the user knows that a redundant encoding is available. This routine returns whether the \p hint is set for \p instr.