pub unsafe extern "C" fn instr_is_floating_ex(
instr: *mut instr_t,
type_: *mut dr_fp_type_t,
) -> bool_Expand description
Returns true iff \p instr is a floating point instruction. @param[in] instr The instruction to query @param[out] type If the return value is true and \p type is non-NULL, the type of the floating point operation is written to \p type. \deprecated Prefer instr_is_floating_type() which uses the more general #dr_instr_category_t.