instr_is_opnd_store_source

Function instr_is_opnd_store_source 

pub unsafe extern "C" fn instr_is_opnd_store_source(
    store_instr: *mut instr_t,
    source_ordinal: c_int,
) -> bool_
If \p store_instr is not a store (instr_writes_memory() returns false), returns false. If \p store_instr is a store (instr_writes_memory() returns true), returns whether its source operand with index \p source_ordinal (as passed to instr_get_src()) is a source for the value that is stored. (If not, it may be an address register that is updated for pre-index or post-index writeback forms, or some other source that does not directly affect the value written to memory.)