instr_is_reg_spill_or_restore

Function instr_is_reg_spill_or_restore 

pub unsafe extern "C" fn instr_is_reg_spill_or_restore(
    drcontext: *mut c_void,
    instr: *mut instr_t,
    tls: *mut bool_,
    spill: *mut bool_,
    reg: *mut reg_id_t,
    offs: *mut uint,
) -> bool_
Returns whether \p instr is a register spill or restore, whether it was created by dr_save_reg(), dr_restore_reg(), dr_insert_read_raw_tls(), dr_insert_write_raw_tls(), routines that call the aforementioned routines (e.g., dr_save_arith_flags()), or DR’s own internal spills and restores. Returns information about the spill/restore in the OUT parameters. The returned \p offs is the raw offset in bytes from the TLS segment base, the stolen register base, or the thread-private context area.