pub unsafe extern "C" fn instr_is_wow64_syscall(
instr: *mut instr_t,
) -> bool_Expand description
Returns true iff \p instr is the indirect transfer from the 32-bit ntdll.dll to the wow64 system call emulation layer. This instruction will also return true for instr_is_syscall, as well as appear as an indirect call, so clients modifying indirect calls may want to avoid modifying this type.
\note Windows-only