instr_predicate_triggered

Function instr_predicate_triggered 

pub unsafe extern "C" fn instr_predicate_triggered(
    instr: *mut instr_t,
    mc: *mut dr_mcontext_t,
) -> dr_pred_trigger_t
Given the machine context \p mc, returns whether or not the predicated instruction \p instr will execute. Currently condition-code predicates are supported and OP_bsf and OP_bsr from #DR_PRED_COMPLEX; other instances of #DR_PRED_COMPLEX are not supported. \p mc->flags must include #DR_MC_CONTROL for condition-code predicates, and additionally #DR_MC_INTEGER for OP_bsf and OP_bsr.

\note More complex predicates will be added in the future and they may require additional state in \p mc.