instr_reads_from_reg

Function instr_reads_from_reg 

pub unsafe extern "C" fn instr_reads_from_reg(
    instr: *mut instr_t,
    reg: reg_id_t,
    flags: dr_opnd_query_flags_t,
) -> bool_
Assumes that reg is a DR_REG_ constant. Returns true iff at least one of instr’s operands reads from a register that overlaps reg (checks both source operands and addressing registers used in destination operands).

Returns false for multi-byte nops with an operand using reg.

Which operands are considered to be accessed for conditionally executed instructions are controlled by \p flags. As a special case, the addressing registers inside a destination memory operand are covered by DR_QUERY_INCLUDE_COND_SRCS rather than DR_QUERY_INCLUDE_COND_DSTS.