pub unsafe extern "C" fn instr_reads_memory(
instr: *mut instr_t,
) -> bool_Expand description
Returns true iff any of \p instr’s source operands is a memory reference.
Unlike opnd_is_memory_reference(), this routine conisders the semantics of the instruction and returns false for both multi-byte nops with a memory operand and for the #OP_lea instruction, as they do not really reference the memory. It does return true for prefetch instructions.
If \p instr is predicated (see instr_is_predicated()), the memory reference may not always be accessed.