instr_set_app

Function instr_set_app 

pub unsafe extern "C" fn instr_set_app(instr: *mut instr_t)
Sets \p instr as an application (non-meta) instruction. An application instruction might be mangled by DR if necessary, e.g., to create an exit stub for a branch instruction. All application instructions that are added to basic blocks or traces should have their translation fields set (via #instr_set_translation()).