instr_set_encoding_hint

Function instr_set_encoding_hint 

pub unsafe extern "C" fn instr_set_encoding_hint(
    instr: *mut instr_t,
    hint: dr_encoding_hint_type_t,
) -> *mut instr_t
Each instruction may store a hint for how the instruction should be encoded if redundant encodings are available. This presumes that the user knows that a redundant encoding is available. This routine sets the \p hint for \p instr. Returns \p instr (for easy chaining).