pub unsafe extern "C" fn instr_set_isa_mode(
instr: *mut instr_t,
mode: dr_isa_mode_t,
) -> bool_Expand description
Each instruction stores the processor mode under which it should be interpreted. This routine sets the mode for \p instr.
pub unsafe extern "C" fn instr_set_isa_mode(
instr: *mut instr_t,
mode: dr_isa_mode_t,
) -> bool_Each instruction stores the processor mode under which it should be interpreted. This routine sets the mode for \p instr.