pub unsafe extern "C" fn instr_set_meta(instr: *mut instr_t)Expand description
Sets \p instr as a meta instruction. A meta instruction will not be mangled by DR in any way, which is necessary to have DR not create an exit stub for a branch instruction. Meta instructions should not fault (unless such faults are handled by the client) and are not considered application instructions but rather added instrumentation code (see #dr_register_bb_event() for further information).