instr_set_meta_may_fault

Function instr_set_meta_may_fault 

pub unsafe extern "C" fn instr_set_meta_may_fault(
    instr: *mut instr_t,
    val: bool_,
)
\deprecated Any meta instruction can fault if it has a non-NULL translation field and the client fully handles all of its faults, so this routine is no longer needed.