instr_set_ok_to_emit

Function instr_set_ok_to_emit 

pub unsafe extern "C" fn instr_set_ok_to_emit(
    instr: *mut instr_t,
    val: bool_,
)
Set \p instr to “ok to emit” if \p val is true and “not ok to emit” if \p val is false. An instruction that should not be emitted is treated normally by DR for purposes of exits but is not placed into the cache. It is used for final jumps that are to be elided.