instr_set_translation

Function instr_set_translation 

pub unsafe extern "C" fn instr_set_translation(
    instr: *mut instr_t,
    addr: app_pc,
) -> *mut instr_t
Sets the translation pointer for \p instr, used to recreate the application address corresponding to this instruction. When adding or modifying instructions that are to be considered application instructions (i.e., non meta-instructions: see #instr_is_app), the translation should always be set. Pick the application address that if executed will be equivalent to restarting \p instr. Currently the translation address must lie within the existing bounds of the containing code block. Returns the supplied \p instr (for easy chaining). Use #instr_get_app_pc to see the current value of the translation.