instr_writes_to_reg

Function instr_writes_to_reg 

pub unsafe extern "C" fn instr_writes_to_reg(
    instr: *mut instr_t,
    reg: reg_id_t,
    flags: dr_opnd_query_flags_t,
) -> bool_
Assumes that \p reg is a DR_REG_ constant. Returns true iff at least one of \p instr’s destination operands is a register operand for a register that overlaps \p reg. Which operands are considered to be accessed for conditionally executed instructions are controlled by \p flags.