instr_zeroes_ymmh

Function instr_zeroes_ymmh 

pub unsafe extern "C" fn instr_zeroes_ymmh(
    instr: *mut instr_t,
) -> bool_
Returns true iff \p instr writes to an xmm register and zeroes the top half of the corresponding ymm register as a result (some instructions preserve the top half while others zero it when writing to the bottom half). This zeroing will occur even if \p instr is predicated (see instr_is_predicated()).