pub unsafe extern "C" fn instrlist_insert_mov_instr_addr(
drcontext: *mut c_void,
src_inst: *mut instr_t,
encode_estimate: *mut byte,
dst: opnd_t,
ilist: *mut instrlist_t,
where_: *mut instr_t,
first: *mut *mut instr_t,
last: *mut *mut instr_t,
)Expand description
Create meta instructions for storing the address of \p src_inst to \p dst, and then insert them into \p ilist prior to \p where. The \p encode_estimate parameter, used only for 64-bit mode, indicates whether the final address of \p src_inst, when it is encoded later, will fit in 32 bits or needs 64 bits. If the encoding will be in DynamoRIO’s code cache, pass NULL. If the final encoding location is unknown, pass a high address to be on the safe side. Pointers to the first and last created meta instructions are returned in \p first and \p last, unless only one meta instruction is created, in which case NULL is returned in last. If the instruction is a no-op (when dst is the zero register on AArch64) then no instructions are created and NULL is returned in first and last.