pub unsafe extern "C" fn instrlist_insert_push_immed_ptrsz(
drcontext: *mut c_void,
val: ptr_int_t,
ilist: *mut instrlist_t,
where_: *mut instr_t,
first: *mut *mut instr_t,
last: *mut *mut instr_t,
)Expand description
Create meta instructions for pushing pointer-size integer \p val on the stack, and then insert them into \p ilist prior to \p where. Pointers to the first and last created meta instructions are returned in \p first and \p last, unless only one meta instruction is created, in which case NULL is returned in last.