instrlist_last_app

Function instrlist_last_app 

pub unsafe extern "C" fn instrlist_last_app(
    ilist: *mut instrlist_t,
) -> *mut instr_t
Returns the last application (non-meta) instruction in the instruction list \p ilist.

\note All preceding meta instructions will be skipped.

\note We recommend using this routine during the phase of application code analysis, as any non-app instructions present are guaranteed to be ok to skip. However, caution should be exercised if using this routine after any instrumentation insertion has already happened, as instrumentation might affect register usage or other factors being analyzed.