instrlist_set_translation_target

Function instrlist_set_translation_target 

pub unsafe extern "C" fn instrlist_set_translation_target(
    ilist: *mut instrlist_t,
    pc: app_pc,
)
All future instructions inserted into \p ilist that do not have raw bits will have instr_set_translation() called with \p pc as the target. This is a convenience routine to make it easy to have the same code generate non-translation and translation instructions, and it does not try to enforce that all instructions have translations (e.g., some could be inserted via instr_set_next()).