opnd_add_flags

Function opnd_add_flags 

pub unsafe extern "C" fn opnd_add_flags(
    opnd: opnd_t,
    flags: dr_opnd_flags_t,
) -> opnd_t
Assumes \p opnd is a register operand, base+disp memory reference, or an immediate integer. Sets the flags describing additional properties of the operand to be the current flags plus the \p flags parameter and returns the new operand value.