pub unsafe extern "C" fn opnd_compute_address(
opnd: opnd_t,
mc: *mut dr_mcontext_t,
) -> app_pcExpand description
Returns the effective address of \p opnd, computed using the passed-in register values. If \p opnd is a far address, ignores that aspect except for TLS references on Windows (fs: for 32-bit, gs: for 64-bit) or typical fs: or gs: references on Linux. For far addresses the calling thread’s segment selector is used. \p mc->flags must include DR_MC_CONTROL and DR_MC_INTEGER.
\note This routine does not support vector addressing (via VSIB, introduced in AVX2). Use instr_compute_address(), instr_compute_address_ex(), or instr_compute_address_ex_pos() instead.