pub unsafe extern "C" fn opnd_create_immed_int(
i: ptr_int_t,
data_size: opnd_size_t,
) -> opnd_tExpand description
Returns a signed immediate integer operand with value \p i and size \p data_size; \p data_size must be a OPSZ_ constant.
pub unsafe extern "C" fn opnd_create_immed_int(
i: ptr_int_t,
data_size: opnd_size_t,
) -> opnd_tReturns a signed immediate integer operand with value \p i and size \p data_size; \p data_size must be a OPSZ_ constant.