pub unsafe extern "C" fn opnd_create_immed_int64(
i: int64,
data_size: opnd_size_t,
) -> opnd_tExpand description
Returns an unsigned immediate integer operand with value \p i and size \p data_size; \p data_size must be a OPSZ_ constant. This operand can be distinguished from a regular immediate integer operand by the flag #DR_OPND_MULTI_PART in opnd_get_flags() which tells the caller to use opnd_get_immed_int64() to retrieve the full value. \note 32-bit only: use opnd_create_immed_int() for 64-bit architectures.