opnd_create_mem_instr

Function opnd_create_mem_instr 

pub unsafe extern "C" fn opnd_create_mem_instr(
    instr: *mut instr_t,
    disp: c_short,
    data_size: opnd_size_t,
) -> opnd_t
Returns a memory reference operand whose value will be the encoded address of \p instr plus the 16-bit displacement \p disp. For 32-bit mode, it will be encoded just like an absolute address (opnd_create_abs_addr()); for 64-bit mode, it will be encoded just like a pc-relative address (opnd_create_rel_addr()). This operand can be used anywhere a regular memory operand can be used. Its size is \p data_size.

\note This operand will return false to opnd_is_instr(), opnd_is_rel_addr(), and opnd_is_abs_addr(). It is a separate type.