pub unsafe extern "C" fn opnd_defines_use(
def: opnd_t,
use_: opnd_t,
) -> bool_Expand description
Returns true iff \p def, considered as a write, affects \p use. Is conservative, so if both \p def and \p use are memory references, will return true unless it can disambiguate them based on their registers and displacement.