opnd_disassemble_to_buffer

Function opnd_disassemble_to_buffer 

pub unsafe extern "C" fn opnd_disassemble_to_buffer(
    drcontext: *mut c_void,
    opnd: opnd_t,
    buf: *mut c_char,
    bufsz: usize,
) -> usize
Prints the operand \p opnd to the buffer \p buf. Always null-terminates, and will not print more than \p bufsz characters, which includes the final null character. Returns the number of characters printed, not including the final null. The default is to use DR’s custom syntax (see disassemble_set_syntax()).