pub unsafe extern "C" fn opnd_get_disp(opnd: opnd_t) -> c_intExpand description
Assumes \p opnd is a (near or far) base+disp memory reference. Returns the displacement. On ARM, the displacement is always a non-negative value, and the presence or absence of #DR_OPND_NEGATED in opnd_get_flags() determines whether to add or subtract from the base register.