opnd_get_immed_float

Function opnd_get_immed_float 

pub unsafe extern "C" fn opnd_get_immed_float(opnd: opnd_t) -> f32
Assumes \p opnd is an immediate float and returns its value. The caller’s code should use proc_save_fpstate() or be inside a clean call that has requested to preserve the floating-point state.