opnd_set_disp

Function opnd_set_disp 

pub unsafe extern "C" fn opnd_set_disp(opnd: *mut opnd_t, disp: c_int)
Set the displacement of a memory reference operand \p opnd to \p disp. On ARM, a negative value for \p disp will be converted into a positive value with #DR_OPND_NEGATED set in opnd_get_flags().