pub unsafe extern "C" fn opnd_size_in_bits(size: opnd_size_t) -> uintExpand description
Assumes \p size is an OPSZ_ constant, typically obtained from opnd_get_size() or reg_get_size(). Returns the number of bits the OPSZ_ constant represents. If OPSZ_ is a variable-sized size, returns the default size, which may or may not match the actual size decided up on at encoding time (that final size depends on other operands).