pub unsafe extern "C" fn proc_bump_to_end_of_cache_line(
sz: ptr_uint_t,
) -> ptr_uint_tExpand description
Returns n >= \p sz such that n is a multiple of the cache line size.
pub unsafe extern "C" fn proc_bump_to_end_of_cache_line(
sz: ptr_uint_t,
) -> ptr_uint_tReturns n >= \p sz such that n is a multiple of the cache line size.