proc_get_family

Function proc_get_family 

pub unsafe extern "C" fn proc_get_family() -> uint
Returns the processor family as given by the cpuid instruction, adjusted by the extended family as described in the Intel documentation. The FAMILY_ constants identify important family values.