proc_get_model

Function proc_get_model 

pub unsafe extern "C" fn proc_get_model() -> uint
Returns the processor model as given by the cpuid instruction, adjusted by the extended model as described in the Intel documentation. The MODEL_ constants identify important model values.