pub unsafe extern "C" fn proc_restore_fpstate(buf: *mut byte)Expand description
Restores the x87 floating point state from the buffer \p buf. On x86, the buffer must be 16-byte-aligned, and it must be 512 (#DR_FPSTATE_BUF_SIZE) bytes for processors with the FXSR feature, and 108 bytes for those without (where this routine does not support 16-bit operand sizing). On ARM/AArch64, nothing needs to be restored as the SIMD/FP registers are restored together with the general-purpose registers.
\note proc_fpstate_save_size() can be used to determine the particular size needed.
When the FXSR feature is present, the fxsave format matches the bitwidth of the ISA mode of the current thread (see dr_get_isa_mode()).