proc_set_vendor

Function proc_set_vendor 

pub unsafe extern "C" fn proc_set_vendor(new_vendor: uint) -> c_int
Sets the vendor to the given VENDOR_ constant. This function is supplied to support decoding or encoding with respect to other than the current processor being executed on. The change in vendor will be seen by the decoder and encoder, as well as the rest of the system. \return the prior vendor, or -1 on an invalid argument.