pub unsafe extern "C" fn reg_get_value_ex(
reg: reg_id_t,
mc: *mut dr_mcontext_t,
val: *mut byte,
) -> bool_Expand description
Returns the value of the register \p reg as stored in \p mc, or for an mmx register as stored in the physical register. Up to sizeof(dr_zmm_t) bytes will be written to \p val.
This routine also supports reading AVX-512 mask registers. In this case, sizeof(dr_opmask_t) bytes will be written to \p val.
This routine does not support floating-point registers.
\note \p mc->flags must include the appropriate flag for the requested register.