reg_is_gpr

Function reg_is_gpr 

pub unsafe extern "C" fn reg_is_gpr(reg: reg_id_t) -> bool_
Assumes that \p reg is a DR_REG_ constant. Returns true iff it refers to a General Purpose Register, i.e., rax, rcx, rdx, rbx, rsp, rbp, rsi, rdi, or a subset.