reg_is_stolen

Function reg_is_stolen 

pub unsafe extern "C" fn reg_is_stolen(reg: reg_id_t) -> bool_
Assumes that \p reg is a DR_REG_ constant. Returns true iff \p reg is stolen by DynamoRIO for internal use.

\note The register stolen by DynamoRIO may not be used by the client for instrumentation. Use dr_insert_get_stolen_reg() and dr_insert_set_stolen_reg() to get and set the application value of the stolen register in the instrumentation. Reference \ref sec_reg_stolen for more information.