reg_set_value_ex

Function reg_set_value_ex 

pub unsafe extern "C" fn reg_set_value_ex(
    reg: reg_id_t,
    mc: *mut dr_mcontext_t,
    val_buf: *mut byte,
) -> bool_
Sets the register \p reg in the passed in mcontext \p mc to the value stored in the buffer \p val_buf.

\p mc->flags must include DR_MC_CONTROL and DR_MC_INTEGER.

Unlike \p reg_set_value, this function supports not only general purpose registers, but SIMD registers too. Does not yet support MMX registers.

Up to sizeof(dr_zmm_t) bytes will be read from \p val_buf. It is up to the user to ensure correct buffer size.

Returns false if the register is not supported.