_dr_kernel_xfer_info_t

Struct _dr_kernel_xfer_info_t 

#[repr(C)]
pub struct _dr_kernel_xfer_info_t { pub type_: dr_kernel_xfer_type_t, pub source_mcontext: *const dr_mcontext_t, pub target_pc: app_pc, pub target_xsp: reg_t, pub sig: c_int, }
Data structure passed for dr_register_kernel_xfer_event().

Fields

type_: dr_kernel_xfer_type_t

The type of event.

source_mcontext: *const dr_mcontext_t

The source machine context which is about to be changed. This may be NULL if it is unknown, which is the case for #DR_XFER_CALLBACK_DISPATCHER. For #DR_XFER_RSEQ_ABORT, due to the constraints of handling restartable sequences, the abort PC will point prior to the committing store, while that store already executed during instrumentation. We recommend that clients treat the store as never-executed in that situation, if possible, to produce a more-representative sequence.

target_pc: app_pc

The target program counter of the transfer. To obtain the full target state, call dr_get_mcontext(). (For efficiency purposes, only frequently needed state is included by default.)

target_xsp: reg_t

The target stack pointer of the transfer. To obtain the full target state, call dr_get_mcontext(). (For efficiency purposes, only frequently needed state is included by default.)

sig: c_int

For #DR_XFER_SIGNAL_DELIVERY and #DR_XFER_SIGNAL_RETURN, the signal number.