#[repr(C)]pub struct _dr_module_import_t {
pub modname: *const c_char,
pub module_import_desc: *mut dr_module_import_desc_t,
}Expand description
Module import data returned from dr_module_import_iterator_next().
String fields point into the importing module image. Robust clients should use DR_TRY_EXCEPT while inspecting the strings in case the module is partially mapped or the app racily unmaps it. The iterator routines themselves handle faults by stopping the iteration.
\note ELF does not import directly from other modules.
Fields
modname: *const c_charSpecified name of the imported module or API set.
module_import_desc: *mut dr_module_import_desc_tOpaque handle that can be passed to dr_symbol_import_iterator_start(). Valid until the original module is unmapped.