_dr_restore_state_info_t

Struct _dr_restore_state_info_t 

#[repr(C)]
pub struct _dr_restore_state_info_t { pub mcontext: *mut dr_mcontext_t, pub raw_mcontext_valid: bool_, pub raw_mcontext: *mut dr_mcontext_t, pub fragment_info: dr_fault_fragment_info_t, }
Data structure passed to a restore_state_ex event handler (see dr_register_restore_state_ex_event()). Contains the machine context at the translation point and other translation information.

Fields

mcontext: *mut dr_mcontext_t

The application machine state at the translation point. The client can update register values and the program counter by changing this context. The client should not change \p mcontext.flags: it should remain DR_MC_ALL.

raw_mcontext_valid: bool_

Whether raw_mcontext is valid.

raw_mcontext: *mut dr_mcontext_t

The raw pre-translated machine state at the translation interruption point inside the code cache. Clients are cautioned when examining code cache instructions to not rely on any details of code inserted other than their own. Modifying this context will not affect the translation.

fragment_info: dr_fault_fragment_info_t

Information about the code fragment inside the code cache at the translation interruption point.