_dr_symbol_export_t

Struct _dr_symbol_export_t 

#[repr(C)]
pub struct _dr_symbol_export_t { pub name: *const c_char, pub addr: app_pc, pub forward: *const c_char, pub ordinal: ptr_uint_t, pub is_indirect_code: bool_, pub is_code: bool_, }
Symbol export data returned from dr_symbol_export_iterator_next().

String fields point into the exporting module image. Robust clients should use DR_TRY_EXCEPT while inspecting the strings in case the module is partially mapped or the app racily unmaps it.

On Windows, the address in \p addr may not be inside the exporting module if it is a forward and has been patched by the loader. In that case, \p forward will be NULL.

Fields

name: *const c_char

< Name of exported symbol, if available.

addr: app_pc

< Address of the exported symbol.

forward: *const c_char

< Forward name, or NULL if not forwarded (Windows only).

ordinal: ptr_uint_t

< Ordinal value (Windows only).

is_indirect_code: bool_

Whether an indirect code object (see dr_export_info_t). (Linux only).

is_code: bool_

< Whether code as opposed to exported data (Linux only).