#[repr(C)]pub struct _dr_symbol_import_t {
pub name: *const c_char,
pub modname: *const c_char,
pub delay_load: bool_,
pub by_ordinal: bool_,
pub ordinal: ptr_uint_t,
}Expand description
Symbol import data returned from dr_symbol_import_iterator_next().
String fields point into the importing module image. Robust clients should use DR_TRY_EXCEPT while inspecting the strings in case the module is partially mapped or the app racily unmaps it.
Fields
name: *const c_char< Name of imported symbol, if available.
modname: *const c_char< Preferred name of module (Windows only).
delay_load: bool_< This import is delay-loaded (Windows only).
by_ordinal: bool_< Import is by ordinal, not name (Windows only).
ordinal: ptr_uint_t< Ordinal value (Windows only).