_dr_syscall_result_info_t

Struct _dr_syscall_result_info_t 

#[repr(C)]
pub struct _dr_syscall_result_info_t { pub size: usize, pub succeeded: bool_, pub value: reg_t, pub high: reg_t, pub use_high: bool_, pub use_errno: bool_, pub errno_value: uint, }
Data structure used to obtain or modify the result of an application system call by dr_syscall_get_result_ex() and dr_syscall_set_result_ex().

Fields

size: usize

The caller should set this to the size of the structure.

succeeded: bool_

Indicates whether the system call succeeded or failed. For dr_syscall_set_result_ex(), this requests that DR set any additional machine state, if any, used by the particular plaform that is not part of \p value to indicate success or failure (e.g., on MacOS the carry flag is used to indicate success).

For Windows, the success result from dr_syscall_get_result_ex() should only be relied upon for ntoskrnl system calls. For other Windows system calls (such as win32k.sys graphical (NtGdi) or user (NtUser) system calls), computing success depends on each particular call semantics and is beyond the scope of this routine (consider using the “drsyscall” Extension instead).

For Mach syscalls on MacOS, the success result from dr_syscall_get_result_ex() should not be relied upon. Computing success depends on each particular call semantics and is beyond the scope of this routine (consider using the “drsyscall” Extension instead).

value: reg_t

The raw main value returned by the system call. See also the \p high field.

high: reg_t

On some platforms (such as MacOS), a 32-bit application’s system call can return a 64-bit value. For such calls, this field will hold the top 32 bit bits, if requested by \p use_high. It is up to the caller to know which system calls have 64-bit return values. System calls that return only 32-bit values do not clear the upper bits. Consider using the “drsyscall” Extension in order to obtain per-system-call semantic information, including return type.

use_high: bool_

This should be set by the caller, and only applies to 32-bit system calls. For dr_syscall_get_result_ex(), this requests that DR fill in the \p high field. For dr_syscall_set_result_ex(), this requests that DR set the high 32 bits of the application-facing result to the value in the \p high field.

use_errno: bool_

This should be set by the caller. For dr_syscall_get_result_ex(), this requests that DR fill in the \p errno_value field. For dr_syscall_set_result_ex(), this requests that DR set the \p value to indicate the particular error code in \p errno_value.

errno_value: uint

If requested by \p use_errno, if a system call fails (i.e., \p succeeded is false) dr_syscall_get_result_ex() will set this field to the absolute value of the error code returned (i.e., on Linux, it will be inverted from what the kernel directly returns, in order to facilitate cross-platform clients that operate on both Linux and MacOS). For Linux and Macos, when \p succeeded is true, \p errno_value is set to 0.

If \p use_errno is set for dr_syscall_set_result_ex(), then this value will be stored as the system call’s return value, negated if necessary for the underlying platform. In that case, \p value will be ignored.