#[repr(C)]pub struct _dr_vg_client_request_t {
pub request: ptr_uint_t,
pub args: [ptr_uint_t; 5],
pub default_result: ptr_uint_t,
}Expand description
Defines the Valgrind client request object, which is constructed by each instance of a Valgrind annotation in the target app. An instance is passed to Valgrind annotation callback functions to make the arguments available. Some arguments may be undefined for some Valgrind client requests; see the Valgrind documentation for each specific Valgrind client request for details about the arguments.
Fields
request: ptr_uint_targs: [ptr_uint_t; 5]default_result: ptr_uint_tTrait Implementations
Sourceimpl Clone for _dr_vg_client_request_t
impl Clone for _dr_vg_client_request_t
Sourcefn clone(&self) -> _dr_vg_client_request_t
fn clone(&self) -> _dr_vg_client_request_t
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for _dr_vg_client_request_t
impl Debug for _dr_vg_client_request_t
impl Copy for _dr_vg_client_request_t