_drmgr_priority_t

Struct _drmgr_priority_t 

#[repr(C)]
pub struct _drmgr_priority_t { pub struct_size: usize, pub name: *const c_char, pub before: *const c_char, pub after: *const c_char, pub priority: c_int, }
Specifies the ordering of callbacks for \p drmgr’s events

Fields

struct_size: usize

The size of the drmgr_priority_t struct

name: *const c_char

A name for the callback being registered, to be used by other components when specifying their relative order. This field is mandatory.

before: *const c_char

The name of another callback that the callback being registered should precede. This field is optional and can be NULL.

after: *const c_char

The name of another callback that the callback being registered should follow. This field is optional and can be NULL.

priority: c_int

The numeric priority of the callback. This is the primary field for determining callback order, with lower numbers placed earlier in the callback invocation order. The \p before and \p after requests must have numeric priorities that are smaller than and greater than, respectively, the requesting callback. Numeric ties are invoked in unspecified order.