_module_data_t

Struct _module_data_t 

#[repr(C)]
pub struct _module_data_t { pub __bindgen_anon_1: _module_data_t__bindgen_ty_1, pub end: app_pc, pub entry_point: app_pc, pub flags: uint, pub names: module_names_t, pub full_path: *mut c_char, pub file_version: version_number_t, pub product_version: version_number_t, pub checksum: uint, pub timestamp: uint, pub module_internal_size: usize, pub preferred_base: app_pc, }
Holds information about a loaded module. \note On Linux the start address can be cast to an Elf32_Ehdr or Elf64_Ehdr. \note On Windows the start address can be cast to an IMAGE_DOS_HEADER for use in finding the IMAGE_NT_HEADER and its OptionalHeader. The OptionalHeader can be used to walk the module sections (among other things). See WINNT.H. \note On MacOS the start address can be cast to mach_header or mach_header_64. \note When accessing any memory inside the module (including header fields) user is responsible for guarding against corruption and the possibility of the module being unmapped.

Fields

__bindgen_anon_1: _module_data_t__bindgen_ty_1end: app_pc

Ending address of this module. If the module is not contiguous (which is common on MacOS, and can happen on Linux), this is the highest address of the module, but there can be gaps in between start and end that are either unmapped or that contain other mappings or libraries. Use the segments array to examine each mapped region, and use dr_module_contains_addr() as a convenience routine, rather than checking against [start..end).

entry_point: app_pc

< entry point for this module as specified in the headers

flags: uint

< Reserved, set to 0

names: module_names_t

< struct containing name(s) for this module; use dr_module_preferred_name() to get the preferred name for this module

full_path: *mut c_char

< full path to the file backing this module

file_version: version_number_t

< file version number from .rsrc section

product_version: version_number_t

< product version number from .rsrc section

checksum: uint

< module checksum from the PE headers

timestamp: uint

< module timestamp from the PE headers

module_internal_size: usize

Module internal size (from PE headers SizeOfImage).

preferred_base: app_pc

< The preferred base address of the module.