_module_names_t

Struct _module_names_t 

#[repr(C)]
pub struct _module_names_t { pub module_name: *const c_char, pub file_name: *const c_char, pub exe_name: *const c_char, pub rsrc_name: *const c_char, }
Holds the names of a module. This structure contains multiple fields corresponding to different sources of a module name. Note that some of these names may not exist for certain modules. It is highly likely, however, that at least one name is available. Use dr_module_preferred_name() on the parent _module_data_t to get the preferred name of the module.

Fields

module_name: *const c_char

< On windows this name comes from the PE header exports section (NULL if the module has no exports section). On Linux the name will come from the ELF DYNAMIC program header (NULL if the module has no SONAME entry).

file_name: *const c_char

< The file name used to load this module. Note - on Windows this is not always available.

exe_name: *const c_char

< If this module is the main executable of this process then this is the executable name used to launch the process (NULL for all other modules).

rsrc_name: *const c_char

< The internal name given to the module in its resource section. Will be NULL if the module has no resource section or doesn’t set this field within it.