#[repr(C)]pub struct _tracedump_stub_data {
pub cti_offs: c_int,
pub stub_pc: app_pc,
pub target: app_pc,
pub linked: bool_,
pub stub_size: c_int,
pub count: _tracedump_stub_data__bindgen_ty_1,
pub stub_code: [byte; 1],
}Expand description
The format of a stub in a trace dump file.
Fields
cti_offs: c_int< Offset from the start of the fragment.
stub_pc: app_pc< Code cache address of the stub.
target: app_pc< Target of the stub.
linked: bool_< Whether the stub is linked to its target.
stub_size: c_int< Length of stub_code array
count: _tracedump_stub_data__bindgen_ty_1< Which field is present depends on the first entry in the file, which indicates the linkcount size.
stub_code: [byte; 1]Code for exit stubs. Only present if: stub_pc < cache_start_pc || stub_pc >= cache_start_pc+code_size). The actual size of the array varies and is indicated by the stub_size field.