dr_emit_flags_t

Type Alias dr_emit_flags_t 

pub type dr_emit_flags_t = c_int;
Flags controlling the behavior of basic blocks and traces when emitted into the code cache. These flags are bitmasks that can be combined by or-ing together. For multiple clients, the flags returned by each client are or-ed together.