dr_exception_t

Type Alias dr_exception_t 

pub type dr_exception_t = _dr_exception_t;
Data structure passed with an exception event. Contains the machine context and the Win32 exception record.

Aliased Type

#[repr(C)]
pub struct dr_exception_t { pub mcontext: *mut _dr_mcontext_t, pub record: *mut _EXCEPTION_RECORD, pub raw_mcontext: *mut _dr_mcontext_t, pub fault_fragment_info: _dr_fault_fragment_info_t, }

Fields

mcontext: *mut _dr_mcontext_t

Machine context at exception point. The client should not change \p mcontext->flags: it should remain DR_MC_ALL.

record: *mut _EXCEPTION_RECORD

< Win32 exception record.

raw_mcontext: *mut _dr_mcontext_t

The raw pre-translated machine state at the exception interruption point inside the code cache. Clients are cautioned when examining code cache instructions to not rely on any details of code inserted other than their own. The client should not change \p raw_mcontext.flags: it should remain DR_MC_ALL.

fault_fragment_info: _dr_fault_fragment_info_t

Information about the code fragment inside the code cache at the exception interruption point.