dr_stats_t

Type Alias dr_stats_t 

pub type dr_stats_t = _dr_stats_t;
Used by dr_get_stats() and dr_app_stop_and_cleanup_with_stats()

Aliased Type

#[repr(C)]
pub struct dr_stats_t {
Show 15 fields pub size: usize, pub basic_block_count: u64, pub peak_num_threads: u64, pub num_threads_created: u64, pub synchs_not_at_safe_spot: u64, pub peak_vmm_blocks_unreach_heap: u64, pub peak_vmm_blocks_unreach_stack: u64, pub peak_vmm_blocks_unreach_special_heap: u64, pub peak_vmm_blocks_unreach_special_mmap: u64, pub peak_vmm_blocks_reach_heap: u64, pub peak_vmm_blocks_reach_cache: u64, pub peak_vmm_blocks_reach_special_heap: u64, pub peak_vmm_blocks_reach_special_mmap: u64, pub num_native_signals: u64, pub num_cache_exits: u64,
}

Fields

size: usize

The size of this structure. Set this to sizeof(dr_stats_t).

basic_block_count: u64

The total number of basic blocks ever built so far, globally. This includes duplicates and blocks that were deleted for consistency or capacity reasons or thread-private caches.

peak_num_threads: u64

Peak number of simultaneous threads under DR control.

num_threads_created: u64

Accumulated total number of threads encountered by DR.

synchs_not_at_safe_spot: u64

Thread synchronization attempts retried due to the target thread being at an un-translatable spot.

peak_vmm_blocks_unreach_heap: u64

Peak number of memory blocks used for unreachable heaps.

peak_vmm_blocks_unreach_stack: u64

Peak number of memory blocks used for (unreachable) thread stacks.

peak_vmm_blocks_unreach_special_heap: u64

Peak number of memory blocks used for unreachable specialized heaps.

peak_vmm_blocks_unreach_special_mmap: u64

Peak number of memory blocks used for other unreachable mappings.

peak_vmm_blocks_reach_heap: u64

Peak number of memory blocks used for reachable heaps.

peak_vmm_blocks_reach_cache: u64

Peak number of memory blocks used for (reachable) code caches.

peak_vmm_blocks_reach_special_heap: u64

Peak number of memory blocks used for reachable specialized heaps.

peak_vmm_blocks_reach_special_mmap: u64

Peak number of memory blocks used for other reachable mappings.

num_native_signals: u64

Signals delivered to native threads.

num_cache_exits: u64

Number of exits from the code cache.