drext_status_t

Type Alias drext_status_t 

pub type drext_status_t = c_int;
Indicates the status of an extension API call. For more details, see the documentation for the specific API call. Indicates the status of an extension API call. For more details, see the documentation for the specific API call.