pub type drmgr_priority_t = _drmgr_priority_t;Expand description
Specifies the ordering of callbacks for \p drmgr’s events
Aliased Type
#[repr(C)]pub struct drmgr_priority_t {
pub struct_size: usize,
pub name: *const i8,
pub before: *const i8,
pub after: *const i8,
pub priority: i32,
}Fields
struct_size: usizeThe size of the drmgr_priority_t struct
name: *const i8A name for the callback being registered, to be used by other components when specifying their relative order. This field is mandatory.
before: *const i8The name of another callback that the callback being registered should precede. This field is optional and can be NULL.
after: *const i8The name of another callback that the callback being registered should follow. This field is optional and can be NULL.
priority: i32The numeric priority of the callback. This is the primary field for determining callback order, with lower numbers placed earlier in the callback invocation order. The \p before and \p after requests must have numeric priorities that are smaller than and greater than, respectively, the requesting callback. Numeric ties are invoked in unspecified order.