emulated_instr_t

Type Alias emulated_instr_t 

pub type emulated_instr_t = _emulated_instr_t;
Holds data about an emulated instruction, typically populated by an emulation client and read by an observational client.

\note The emulated \p instr is part of the label represented by \p emulated_instr_t and as such it will be freed when the label created by drmgr_insert_emulation_start() is freed.

Aliased Type

#[repr(C)]
pub struct emulated_instr_t { pub size: usize, pub pc: *mut u8, pub instr: *mut instr_t, pub flags: i32, }

Fields

size: usize

< Size of this struct, used for API compatibility checks.

pc: *mut u8

< The PC address of the emulated instruction.

instr: *mut instr_t

< The emulated instruction. See Note above.

flags: i32

< Flags further describing the emulation.