pub type instrlist_t = _instrlist_t;Expand description
The opaque type used to represent linear lists of #instr_t instructions.
Aliased Type
pub struct instrlist_t { /* private fields */ }pub type instrlist_t = _instrlist_t;The opaque type used to represent linear lists of #instr_t instructions.
pub struct instrlist_t { /* private fields */ }