tracedump_stub_data_t

Type Alias tracedump_stub_data_t 

pub type tracedump_stub_data_t = _tracedump_stub_data;
The format of a stub in a trace dump file.

Aliased Type

#[repr(C)]
pub struct tracedump_stub_data_t { pub cti_offs: i32, pub stub_pc: *mut u8, pub target: *mut u8, pub linked: i8, pub stub_size: i32, pub count: _tracedump_stub_data__bindgen_ty_1, pub stub_code: [u8; 1], }

Fields

cti_offs: i32

< Offset from the start of the fragment.

stub_pc: *mut u8

< Code cache address of the stub.

target: *mut u8

< Target of the stub.

linked: i8

< Whether the stub is linked to its target.

stub_size: i32

< Length of stub_code array

count: _tracedump_stub_data__bindgen_ty_1

< Which field is present depends on the first entry in the file, which indicates the linkcount size.

stub_code: [u8; 1]

Code for exit stubs. Only present if: stub_pc < cache_start_pc || stub_pc >= cache_start_pc+code_size). The actual size of the array varies and is indicated by the stub_size field.