pub unsafe extern "C" fn __wrap_strdup(
str_: *const c_char,
) -> *mut c_charExpand description
Allocates memory for a new string identical to ‘str’ and copies the contents of ‘str’ into the new string, including a terminating null. Memory must be freed with __wrap_free(). The __wrap routines are intended to be used with ld’s -wrap option; see __wrap_malloc() for more information. The returned address is guaranteed to be double-pointer-aligned: aligned to 16 bytes for 64-bit; aligned to 8 bytes for 32-bit.