pub unsafe extern "C" fn decode_as_bb(
drcontext: *mut c_void,
start_pc: *mut byte,
) -> *mut instrlist_tExpand description
Client routine to decode instructions at an arbitrary app address, following all the rules that DynamoRIO follows internally for terminating basic blocks. Note that DynamoRIO does not validate that \p start_pc is actually the first instruction of a basic block. \note Caller is reponsible for freeing the list and its instrs!