pub unsafe extern "C" fn decode_eflags_usage(
drcontext: *mut c_void,
pc: *mut byte,
usage: *mut uint,
flags: dr_opnd_query_flags_t,
) -> *mut byteExpand description
Decodes only enough of the instruction at address \p pc to determine its eflags usage, which is returned in \p usage as EFLAGS_ constants or’ed together. Returns the address of the next byte after the decoded instruction. Returns NULL on decoding an invalid instruction.