pub unsafe extern "C" fn disassemble(
drcontext: *mut c_void,
pc: *mut byte,
outfile: file_t,
) -> *mut byteExpand description
Decodes and then prints the instruction at address \p pc to file \p outfile. The default is to use DR’s custom syntax (see disassemble_set_syntax()). Returns the address of the subsequent instruction, or NULL if the instruction at \p pc is invalid.