pub unsafe extern "C" fn dr_allow_unsafe_static_behavior()Expand description
The #DR_DISALLOW_UNSAFE_STATIC declaration requests that DR perform sanity checks to ensure that client libraries will also operate safely when linked statically into an application. This overrides that request, facilitating having runtime options that are not supported in a static context.