pub unsafe extern "C" fn dr_annotation_pass_pc(
annotation_name: *const c_char,
) -> bool_Expand description
Can only be called on an annotation already registered with dr_annotation_register_call(). When the annotation is encountered, the PC of the annotation interruption point will be available in DR scratch slot #SPILL_SLOT_2, which can be read with dr_read_saved_reg().
@param[in] annotation_name The name of the annotation function as it appears in the target app’s source code (unmangled).