pub unsafe extern "C" fn dr_annotation_register_call(
annotation_name: *const c_char,
callee: *mut c_void,
save_fpstate: bool_,
num_args: uint,
call_type: dr_annotation_calling_convention_t,
) -> bool_Expand description
Register a handler for a DR annotation. When the annotation is encountered, it will be replaced with a clean call to the specified callee, which must have the specified number of arguments. Returns true on successful registration.
@param[in] annotation_name The name of the annotation function as it appears in the target app’s source code (unmangled). @param[in] callee The client function to call when an instance of the specified annotation is executed. @param[in] save_fpstate Indicates whether to save floating point state before making the clean call to the callee. @param[in] num_args The number of arguments in the annotation function (must also match the number of arguments in the callee). @param[in] call_type The calling convention of the annotation function as compiled in the target app (x86 only).