pub unsafe extern "C" fn dr_app_running_under_dynamorio() -> bool_Expand description
Indicates whether the current thread is running within the DynamoRIO code cache. Returns \p true only if the current thread is running within the DynamoRIO code cache and returns false othrewise.
\note This routines returns \p false if the current thread is running within the DynamoRIO probe mode.