pub unsafe extern "C" fn dr_delete_file(
filename: *const c_char,
) -> bool_Expand description
Deletes the file referred to by \p filename. Returns true if successful. On both Linux and Windows, if filename refers to a symlink, the symlink will be deleted and not the target of the symlink. On Windows, this will fail to delete any file that was not opened with FILE_SHARE_DELETE and is still open. Relative path support on Windows is identical to that described in dr_open_file().