pub unsafe extern "C" fn dr_fragment_persistable(
drcontext: *mut c_void,
perscxt: *mut c_void,
tag: *mut c_void,
) -> bool_Expand description
Takes in the \p perscxt opaque parameter passed to various persistence events and returns whether the fragment identified by \p tag is being persisted. This routine can be called outside of a persistence event, in which case the \p perscxt parameter should be NULL.