pub unsafe extern "C" fn dr_get_current_directory(
buf: *mut c_char,
bufsz: usize,
) -> bool_Expand description
Returns the current directory for this process in \p buf. On Windows, reading the current directory is considered unsafe except during initialization, as it is stored in user memory and access is not controlled via any standard synchronization.