pub unsafe extern "C" fn dr_get_os_version(
info: *mut dr_os_version_info_t,
) -> bool_Expand description
Returns information about the version of the operating system. Returns whether successful. \note Windows only. \note The Windows API routine GetVersionEx may hide distinctions between versions, such as between Windows 8 and Windows 8.1. DR reports the true low-level version.