pub unsafe extern "C" fn dr_get_tls_field(
drcontext: *mut c_void,
) -> *mut c_voidExpand description
Returns the user-controlled thread-local-storage field. To generate an instruction sequence that reads the drcontext field inline in the code cache, use dr_insert_read_tls_field().