pub unsafe extern "C" fn dr_hashtable_clear(
drcontext: *mut c_void,
htable: *mut c_void,
)Expand description
Removes all entries in a hashtable created by dr_hashtable_create().
@param[in] drcontext Must be the same context passed to dr_hashtable_create(). @param[in] htable A pointer to the table itself, returned by dr_hashtable_create().