pub unsafe extern "C" fn dr_hashtable_lookup(
drcontext: *mut c_void,
htable: *mut c_void,
key: ptr_uint_t,
) -> *mut c_voidExpand description
Queries whether an entry for the given key exists.
@param[in] drcontext Must be the same context passed to dr_hashtable_create(). @param[in] htable A pointer to the table itself, returned by dr_hashtable_create(). @param[in] key The key to query.
@return the payload value for the key that was passed to dr_hashtable_add(), or NULL if no such key is found.