pub unsafe extern "C" fn dr_insert_clean_call_ex(
drcontext: *mut c_void,
ilist: *mut instrlist_t,
where_: *mut instr_t,
callee: *mut c_void,
save_flags: dr_cleancall_save_t,
num_args: uint,
...
)Expand description
Identical to dr_insert_clean_call() except it takes in \p save_flags which allows requests to not save certain state. This is intended for use at application call entry points or other contexts where a client is comfortable making assumptions. Keep in mind that any register that is not saved will not be present in a context obtained from dr_get_mcontext().