pub unsafe extern "C" fn dr_insert_get_seg_base(
drcontext: *mut c_void,
ilist: *mut instrlist_t,
instr: *mut instr_t,
seg: reg_id_t,
reg: reg_id_t,
) -> bool_Expand description
Insert code to get the segment base address pointed to by seg into register reg. In Linux, it is only supported with -mangle_app_seg option. In Windows, it only supports getting base address of the TLS segment.
\return whether successful.