pub unsafe extern "C" fn dr_insert_it_instrs(
drcontext: *mut c_void,
ilist: *mut instrlist_t,
) -> c_intExpand description
Inserts enough OP_it instructions with proper parameters into \p ilist to make all predicated instructions in \p ilist legal in Thumb mode (#DR_ISA_ARM_THUMB). Treats predicated app and tool instructions identically, but marks inserted OP_it instructions as app instructions (see instr_set_app()).
\return the number of OP_it instructions inserted; -1 on error.
\note ARM-only