pub unsafe extern "C" fn dr_insert_set_stolen_reg_value(
drcontext: *mut c_void,
ilist: *mut instrlist_t,
instr: *mut instr_t,
reg: reg_id_t,
) -> bool_Expand description
Insert code to set the value of register \p reg as the application value of the register stolen by DynamoRIO Reference \ref sec_reg_stolen for more information.
\return whether successful.
\note ARM-only