pub unsafe extern "C" fn dr_is_detaching() -> bool_Expand description
Query whether detach is in progress. This is useful for clients that want to avoid the cost of resetting their global state on exit if there is no detaching and thus no chance of re-attaching.