pub unsafe extern "C" fn dr_memory_is_dr_internal( pc: *const byte, ) -> bool_
Returns true iff pc is memory allocated by DR for its own purposes, and would not exist if the application were run natively.