pub unsafe extern "C" fn dr_nonheap_alloc(
size: usize,
prot: uint,
) -> *mut c_voidExpand description
Allocates \p size bytes of memory as a separate allocation from DR’s heap, allowing for separate protection. The \p prot protection should use the DR_MEMPROT_READ, DR_MEMPROT_WRITE, and DR_MEMPROT_EXEC bits. When creating a region to hold dynamically generated code, use this routine in order to create executable memory.