pub unsafe extern "C" fn dr_num_app_args() -> c_intExpand description
Returns the number of command-line arguments passed to the application.
\note Currently, this function is only available on Unix with early injection.
\note An error code may be obtained via dr_get_error_code() when this routine fails.