pub unsafe extern "C" fn dr_persist_start( perscxt: *mut c_void, ) -> app_pc
Takes in the \p perscxt opaque parameter passed to various persistence events and returns the beginning address of the code region being persisted.