pub unsafe extern "C" fn dr_register_clean_call_insertion_event(
func: Option<unsafe extern "C" fn(drcontext: *mut c_void, ilist: *mut instrlist_t, where_: *mut instr_t, call_flags: dr_cleancall_save_t)>,
)Expand description
Registers a callback function that is invoked whenever a clean call is inserted in instrumentation, such as by dr_insert_clean_call(), dr_insert_clean_call_ex(), or dr_insert_clean_call_ex_varg(). ‘where’ is a label with note value #DR_NOTE_CLEAN_CALL_END; the clean call sequence will be inserted prior to the label after all clean call callbacks are finished (so the clean call sequence is not yet visible at the time this callback is invoked).