pub unsafe extern "C" fn dr_registered_process_iterator_next(
iter: *mut dr_registered_process_iterator_t,
process_name: *mut c_char,
dr_root_dir: *mut c_char,
dr_mode: *mut dr_operation_mode_t,
debug: *mut bool_,
dr_options: *mut c_char,
) -> bool_Expand description
Return information about a registered process
\param[in] iter A registered process iterator created with dr_registered_process_iterator_start().
\param[out] process_name The name of the registered process. Callers can pass NULL if this value is not needed. Otherwise the parameter must be a caller-allocated array of length #MAXIMUM_PATH.
\param[out] dr_root_dir The root DynamoRIO directory provided at registration. Callers can pass NULL if this value is not needed. Otherwise, the parameter must be a caller-allocated array of length #MAXIMUM_PATH.
\param[out] dr_mode If the process is registered, the mode provided at registration. Callers can pass NULL if this value is not needed.
\param[out] debug If the process is registered, the debug flag provided at registration. Callers can pass NULL if this value is not needed.
\param[out] dr_options If the process is registered, the extra DynamoRIO parameters provided at registration. Callers can pass NULL if this value is not needed. Otherwise, the parameter must be a caller-allocated array of length #DR_MAX_OPTIONS_LENGTH.
\return true if the information was successfully retrieved.
\note Not yet available on Linux or MacOS.