pub unsafe extern "C" fn dr_set_isa_mode(
drcontext: *mut c_void,
new_mode: dr_isa_mode_t,
old_mode: *mut dr_isa_mode_t,
) -> bool_Expand description
The decode and encode routines use a per-thread persistent flag that indicates which processor mode to use. This routine sets that flag to the indicated value and optionally returns the old value. Be sure to restore the old value prior to any further application execution to avoid problems in mis-interpreting application code.