pub unsafe extern "C" fn dr_swap_to_clean_stack(
drcontext: *mut c_void,
ilist: *mut instrlist_t,
where_: *mut instr_t,
)Expand description
Inserts into \p ilist prior to \p where meta-instruction(s) to save the current esp and switch to this thread’s DR stack. \note The DR stack is limited to 20KB by default; this can be changed with the -stack_size DR runtime parameter. This stack cannot be used to store state that persists beyond a single clean call, code cache execution, or probe callback function execution.