pub unsafe extern "C" fn dr_symbol_export_iterator_start(
handle: module_handle_t,
) -> *mut dr_symbol_export_iterator_tExpand description
Creates an iterator over symbols exported by a module. The iterator returned is invalid until after the first call to dr_symbol_export_iterator_next().
\note To iterate over all symbols in a module and not just those exported, use the \ref page_drsyms.