pub unsafe extern "C" fn dr_syscall_set_result_ex(
drcontext: *mut c_void,
info: *mut dr_syscall_result_info_t,
) -> bool_Expand description
Usable only from a pre-syscall (dr_register_pre_syscall_event()) or post-syscall (dr_register_post_syscall_event()) event. For pre-syscall, should only be used when skipping the system call.
This sets the returned results of the system call as specified in \p info. Returns whether it successfully did so. See the fields of #dr_syscall_result_info_t for details.