pub unsafe extern "C" fn dr_unregister_bb_event(
func: Option<unsafe extern "C" fn(drcontext: *mut c_void, tag: *mut c_void, bb: *mut instrlist_t, for_trace: bool_, translating: bool_) -> dr_emit_flags_t>,
) -> bool_Expand description
Unregister a callback function for the basic block event. \return true if unregistration is successful and false if it is not (e.g., \p func was not registered).
\note We do not recommend unregistering for the basic block event unless it aways returned #DR_EMIT_STORE_TRANSLATIONS (including when \p for_trace is true, or if the client has a trace creation callback that returns #DR_EMIT_STORE_TRANSLATIONS). Unregistering can prevent proper state translation on a later fault or other translation event for this basic block or for a trace that includes this basic block. Instead of unregistering, turn the event callback into a nop.