pub unsafe extern "C" fn dr_unregister_exit_event(
func: Option<unsafe extern "C" fn()>,
) -> bool_Expand description
Unregister a callback function for the process exit event. \return true if unregistration is successful and false if it is not (e.g., \p func was not registered).