pub unsafe extern "C" fn dr_unregister_syswide(
dr_platform: dr_platform_t,
dr_root_dir: *const c_char,
) -> dr_config_status_tExpand description
Disables systemwide injection. Registered applications will not run under DynamoRIO unless explicitly launched with the drrun or drinject tools (or a custom tool that uses the drinjectlib library). On Windows NT, a reboot is required for this to take effect.
\param[in] dr_platform Configurations are kept separate for 32-bit processes and 64-bit processes. This parameter allows selecting which of those to use.
\param[in] dr_root_dir The root DynamoRIO directory.
\return A dr_config_status_t code indicating the result of the operation. The operation will fail if the caller does not have sufficient privileges.
\note Not yet available on Linux or MacOS.