pub unsafe extern "C" fn dr_write_saved_reg(
drcontext: *mut c_void,
slot: dr_spill_slot_t,
value: reg_t,
)Expand description
Can be used from a clean call to modify the value saved in the spill slot \p slot by dr_save_reg() such that a later dr_restore_reg() will see the new value.
\note This routine should only be used during a clean call out of the cache. Use at any other time could corrupt application or DynamoRIO state.