pub unsafe extern "C" fn drmgr_get_emulated_instr_data(
instr: *mut instr_t,
emulated: *mut emulated_instr_t,
) -> bool_Expand description
Loads \p emulated with the emulated instruction data from \p instr set by drmgr_insert_emulation_start().
When calling this function, the \p size field of \p emulated should be set using sizeof(). This allows the API to check for compatibility.
@param[in] instr The label instruction which specifies start of emulation. @param[out] emulated The emulated instruction data.
\return false if the caller’s \p emulated_instr_t is not compatible, true otherwise.