pub unsafe extern "C" fn drmgr_pop_cls(
drcontext: *mut c_void,
) -> bool_Expand description
Pops a callback context from the callback-local storage (cls) context stack for the given thread. This function is automatically called on exit from a Windows callback. Users can invoke it to provide context stacks for their own uses, including Linux signals or layered wrapped functions. Invoking this function will trigger the \p cb_exit_func passed to drmgr_register_cls_field().
Returns false if the context stack has only one entry.