pub unsafe extern "C" fn drmgr_push_cls(
drcontext: *mut c_void,
) -> bool_Expand description
Pushes a new callback context onto the callback-local storage (cls) context stack for the given thread. This function is automatically called on entry to a new Windows callback. Users can invoke it to provide context stacks for their own uses, including Linux signals or layered wrapped functions. Invoking this function will trigger the \p cb_init_func passed to drmgr_register_cls_field(). \return whether successful.