pub unsafe extern "C" fn drmgr_register_low_on_memory_event(
func: Option<unsafe extern "C" fn()>,
) -> bool_Expand description
Registers a callback function \p func for the low-on-memory event. The callback provides a means for the client to free any non-critical data found on the heap, which could avoid a potential out-of-memory crash (particularly on 32-bit). \return whether successful.