pub unsafe extern "C" fn drmgr_register_module_unload_event_user_data(
func: Option<unsafe extern "C" fn(drcontext: *mut c_void, info: *const module_data_t, user_data: *mut c_void)>,
priority: *mut drmgr_priority_t,
user_data: *mut c_void,
) -> bool_Expand description
Registers a callback function for the module unload event, which behaves just like DR’s module unload event dr_register_module_unload_event(). Allows for the passing of user data, \p user_data, which is available upon the execution of the callback. \return whether successful.
See also drmgr_register_module_unload_event_ex().