pub unsafe extern "C" fn drmgr_register_thread_init_event(
func: Option<unsafe extern "C" fn(drcontext: *mut c_void)>,
) -> bool_Expand description
Registers a callback function for the thread initialization event. drmgr calls \p func whenever the application creates a new thread. \return whether successful.