pub unsafe extern "C" fn drmgr_unregister_bb_instrumentation_event(
func: drmgr_analysis_cb_t,
) -> bool_Expand description
Unregisters \p func and its corresponding insertion callback from the second and third instrumentation stages. \return true if unregistration is successful and false if it is not (e.g., \p func was not registered).
The recommendations for dr_unregister_bb_event() about when it is safe to unregister apply here as well.