pub unsafe extern "C" fn drmgr_unregister_bb_instrumentation_ex_event(
app2app_func: drmgr_app2app_ex_cb_t,
analysis_func: drmgr_ilist_ex_cb_t,
insertion_func: drmgr_insertion_cb_t,
instru2instru_func: drmgr_ilist_ex_cb_t,
) -> bool_Expand description
Unregisters the four given callbacks that were registered via drmgr_register_bb_instrumentation_ex_event(). \return true if unregistration is successful and false if it is not (e.g., \p func was not registered).
The recommendations for dr_unregister_bb_event() about when it is safe to unregister apply here as well.