pub unsafe extern "C" fn drmgr_unregister_module_unload_event_user_data(
func: Option<unsafe extern "C" fn(drcontext: *mut c_void, info: *const module_data_t, user_data: *mut c_void)>,
) -> bool_Expand description
Unregister a callback function, that takes user data as a parameter, for the module unload event. \return true if unregistration is successful and false if it is not (e.g., \p func was not registered).
See also drmgr_unregister_module_unload_event().