pub unsafe extern "C" fn drmgr_unregister_opcode_instrumentation_event(
func: drmgr_opcode_insertion_cb_t,
opcode: c_int,
) -> bool_Expand description
Unregisters the opcode-specific callback that was registered via drmgr_register_opcode_instrumentation_event().
\return true if unregistration is successful and false if it is not (e.g., \p func was not registered for the passed opcode \p opcode).
The recommendations for dr_unregister_bb_event() about when it is safe to unregister apply here as well.