pub unsafe extern "C" fn drreg_aflags_liveness(
drcontext: *mut c_void,
inst: *mut instr_t,
value: *mut uint,
) -> drreg_status_tExpand description
Returns in \p value EFLAGS_READ_6 bits telling which arithmetic flags are live at the point of \p inst. If called during drmgr’s insertion phase, \p inst must be the current application instruction.
@return whether successful or an error code on failure.