pub unsafe extern "C" fn drreg_init(
ops: *mut drreg_options_t,
) -> drreg_status_tExpand description
Initializes the drreg extension. Must be called prior to any of the other routines. Can be called multiple times (by separate components, normally) but each call must be paired with a corresponding call to drreg_exit(). The fields of \p ops are combined from multiple calls as described in the documentation for each field. Typically the end-user tool itself specifies these options, with most other library components not directly interacting with drreg (libraries often take in scratch registers from the caller for most of their operations).
@param[in] ops Specifies the optional parameters that control how drreg operates.
@return whether successful or an error code on failure.