pub unsafe extern "C" fn drreg_set_vector_entry(
vec: *mut drvector_t,
reg: reg_id_t,
allowed: bool_,
) -> drreg_status_tExpand description
Sets the entry in \p vec at index \p reg minus #DR_REG_START_GPR to NULL if \p allowed is false or a non-NULL value if \p allowed is true. This is intendend as a convenience routine for setting up the \p reg_allowed parameter to drreg_reserve_register().
@return whether successful or an error code on failure.