pub unsafe extern "C" fn drvector_set_entry(
vec: *mut drvector_t,
idx: uint,
data: *mut c_void,
) -> bool_Expand description
Sets the entry at index \p idx to \p data. For an unsychronized table, the caller is free to directly set the \p array field of \p vec. Entries in between the last set index and \p idx are left uninitialized. Returns whether successful.