pub unsafe extern "C" fn drwrap_get_mcontext(
wrapcxt: *mut c_void,
) -> *mut dr_mcontext_tExpand description
Returns the machine context of the wrapped function represented by \p wrapcxt corresponding to the application state at the time of the pre-function or post-function wrap callback. The pc field is set appropriately. In order for any changes to the returned context to take effect, drwrap_set_mcontext() must be called.
\note if the #DRWRAP_FAST_CLEANCALLS flag is set, caller-saved register values in the fields controlled by #DR_MC_MULTIMEDIA will not contain valid values.