pub unsafe extern "C" fn drwrap_init() -> bool_Expand description
Initializes the drwrap extension. Must be called prior to any of the other routines. Can be called multiple times (by separate components, normally) but each call must be paired with a corresponding call to drwrap_exit().
Some drwrap behavior (such as #DRWRAP_INVERT_CONTROL) must be set by calling drwrap_set_global_flags() before calling this routine.
\return whether successful.