pub unsafe extern "C" fn drwrap_register_post_call_notify(
cb: Option<unsafe extern "C" fn(pc: app_pc)>,
) -> bool_Expand description
Registers a callback \p cb to be called every time a new post-call address is encountered. The intended use is for tools that want faster start-up time by avoiding flushes for inserting wrap instrumentation at post-call sites. A tool can use this callback to record all of the post-call addresses to disk, and use drwrap_mark_as_post_call() during module load of the next execution. It is up to the tool to verify that the module has not changed since its addresses were recorded.
\return whether successful.