pub unsafe extern "C" fn instr_clone(
drcontext: *mut c_void,
orig: *mut instr_t,
) -> *mut instr_tExpand description
Returns a copy of \p orig with separately allocated memory for operands and raw bytes if they were present in \p orig. Only a shallow copy of the \p note field is made. The \p label_cb field will not be copied at all if \p orig is a label instruction.