pub unsafe extern "C" fn instr_compute_address_ex_pos(
instr: *mut instr_t,
mc: *mut dr_mcontext_t,
index: uint,
addr: *mut app_pc,
is_write: *mut bool_,
pos: *mut uint,
) -> bool_Expand description
Performs address calculation in the same manner as instr_compute_address_ex() with additional information of which opnd is used for address computation returned in \p pos. If \p pos is NULL, it is the same as instr_compute_address_ex().
Like instr_reads_memory(), this routine does not consider multi-byte nops that use addressing operands, or the #OP_lea instruction’s source operand, to be memory references.