pub unsafe extern "C" fn instr_create_Ndst_Msrc_varsrc(
drcontext: *mut c_void,
opcode: c_int,
fixed_dsts: uint,
fixed_srcs: uint,
var_srcs: uint,
var_ord: uint,
...
) -> *mut instr_tExpand description
Convenience routine that returns an initialized instr_t allocated on the thread-local heap with opcode \p opcode, \p fixed_dsts destination operands, and \p fixed_srcs plus \p var_srcs source operands. The variable arguments must start with the (fixed) destinations, followed by the fixed sources, followed by the variable sources. The \p var_ord parameter specifies the (0-based) ordinal position within the resulting instruction’s source array at which the variable sources should be placed, allowing them to be inserted in the middle of the fixed sources.