pub unsafe extern "C" fn instr_get_arith_flags(
instr: *mut instr_t,
flags: dr_opnd_query_flags_t,
) -> uintExpand description
Returns \p instr’s arithmetic flags (bottom 6 eflags) use as EFLAGS_ constants (e.g., EFLAGS_READ_CF, EFLAGS_WRITE_OF, etc.) or’ed together. If \p instr’s eflags behavior has not been calculated yet or is invalid, the entire eflags use is calculated and returned (not just the arithmetic flags). Which eflags are considered to be accessed for conditionally executed instructions are controlled by \p flags.