pub unsafe extern "C" fn instr_get_next(
instr: *mut instr_t,
) -> *mut instr_tExpand description
Returns the next instr_t in the instrlist_t that contains \p instr. \note The next pointer for an instr_t is inside the instr_t data structure itself, making it impossible to have on instr_t in two different InstrLists (but removing the need for an extra data structure for each element of the instrlist_t).