pub unsafe extern "C" fn instr_get_opcode_eflags(
opcode: c_int,
) -> uintExpand description
Returns the eflags usage of instructions with opcode \p opcode, as EFLAGS_ constants (e.g., EFLAGS_READ_CF, EFLAGS_WRITE_OF, etc.) or’ed together. If \p opcode is predicated (see instr_is_predicated()) or if the set of flags read or written varies with an operand value, this routine returns the maximal set that might be accessed or written.