pub unsafe extern "C" fn instr_is_cti_short_rewrite(
instr: *mut instr_t,
pc: *mut byte,
) -> bool_Expand description
Returns true iff \p instr’s opcode is OP_loop* or OP_jecxz on x86 or OP_cbz or OP_cbnz on ARM and instr has been transformed to a sequence of instruction that will allow a larger offset. If \p pc != NULL, \p pc is expected to point to the beginning of the encoding of \p instr, and the following instructions are assumed to be encoded in sequence after \p instr. Otherwise, the encoding is expected to be found in \p instr’s allocated bits. / /** This routine does NOT try to decode an opcode in a Level 1 or Level 0 routine, and can thus be called on Level 0 routines. Levels are not exposed in the API anymore, however.