pub unsafe extern "C" fn instr_is_exit_cti(
instr: *mut instr_t,
) -> bool_Expand description
Returns true iff \p instr is a conditional branch, unconditional branch, or indirect branch with a program address target (NOT an instr_t address target) and \p instr is ok to mangle.