pub unsafe extern "C" fn instr_is_meta_may_fault(
instr: *mut instr_t,
) -> bool_Expand description
Return true iff \p instr is not a meta-instruction that can fault (see instr_set_meta_may_fault() for more information).
\deprecated Any meta instruction can fault if it has a non-NULL translation field and the client fully handles all of its faults, so this routine is no longer needed.