pub unsafe extern "C" fn instr_reuse(
drcontext: *mut c_void,
instr: *mut instr_t,
)Expand description
Frees all dynamically allocated storage that was allocated by \p instr, except for allocated bits. Also zeroes out \p instr’s fields, except for raw bit fields, whether \p instr is instr_is_meta(), and the x86 mode of \p instr. \p instr must have been initialized.