pub unsafe extern "C" fn instr_zeroes_zmmh(
instr: *mut instr_t,
) -> bool_Expand description
Returns true iff \p instr writes to an xmm or ymm register and zeroes the top half of the corresponding zmm register as a result (some instructions preserve the top half while others zero it when writing to the bottom half). This zeroing will occur even if \p instr is predicated (see instr_is_predicated()).