pub unsafe extern "C" fn instrlist_clone(
drcontext: *mut c_void,
old: *mut instrlist_t,
) -> *mut instrlist_tExpand description
Allocates a new instrlist_t and for each instr_t in \p old allocates a new instr_t using instr_clone to produce a complete copy of \p old. Each operand that is opnd_is_instr() has its target updated to point to the corresponding instr_t in the new instrlist_t (this routine assumes that all such targets are contained within \p old, and may fault otherwise).