pub unsafe extern "C" fn instrlist_insert_mov_immed_ptrsz(
drcontext: *mut c_void,
val: ptr_int_t,
dst: opnd_t,
ilist: *mut instrlist_t,
where_: *mut instr_t,
first: *mut *mut instr_t,
last: *mut *mut instr_t,
)Expand description
Create meta instructions for storing pointer-size integer \p val to \p dst, and then insert them into \p ilist prior to \p where. Pointers to the first and last created meta instructions are returned in \p first and \p last, unless only one meta instruction is created, in which case NULL is returned in last. If the instruction is a no-op (when dst is the zero register on AArch64) then no instructions are created and NULL is returned in first and last.