pub unsafe extern "C" fn instrlist_set_fall_through_target(
bb: *mut instrlist_t,
tgt: app_pc,
) -> bool_Expand description
Specifies the fall-through target of a basic block if its last instruction is a conditional branch instruction. It can only be called in basic block building event callbacks when the \p for_trace parameter is false, and has NO EFFECT in other cases.