pub unsafe extern "C" fn opnd_create_instr(
instr: *mut instr_t,
) -> opnd_tExpand description
Returns an operand whose value will be the encoded address of \p instr. This operand can be used as an immediate integer or as a direct call or jump target. Its size is always #OPSZ_PTR.