pub unsafe extern "C" fn opnd_create_instr_ex(
instr: *mut instr_t,
size: opnd_size_t,
shift: ushort,
) -> opnd_tExpand description
Returns an operand whose value will be the encoded address of \p instr. This operand can be used as an immediate integer or as a direct call or jump target. Its size is the specified \p size. Its value can be optionally right-shifted by \p shift from the encoded address.