pub unsafe extern "C" fn opnd_create_reg_ex(
r: reg_id_t,
subsize: opnd_size_t,
flags: dr_opnd_flags_t,
) -> opnd_tExpand description
Returns a register operand with additional properties specified by \p flags. If \p subsize is 0, creates a full-sized register; otherwise, creates a partial register in the manner of opnd_create_reg_partial().