pub unsafe extern "C" fn opnd_set_disp_ex(
opnd: *mut opnd_t,
disp: c_int,
encode_zero_disp: bool_,
force_full_disp: bool_,
disp_short_addr: bool_,
)Expand description
Set the displacement and the encoding controls of a memory reference operand:
- If \p encode_zero_disp, a zero value for \p disp will not be omitted;
- If \p force_full_disp, a small value for \p disp will not occupy only one byte.
- If \p disp_short_addr, short (16-bit for 32-bit mode, 32-bit for 64-bit mode) addressing will be used (note that this normally only needs to be specified for an absolute address; otherwise, simply use the desired short registers for base and/or index). \note x86-only.