pub unsafe extern "C" fn proc_get_model() -> uintExpand description
Returns the processor model as given by the cpuid instruction, adjusted by the extended model as described in the Intel documentation. The MODEL_ constants identify important model values.