pub unsafe extern "C" fn reg_is_vector_simd(reg: reg_id_t) -> bool_Expand description
Assumes that \p reg is a DR_REG_ constant. Returns true iff it refers to an SSE or AVX register. In particular, the register must be either an xmm, ymm, or zmm for the function to return true.
This function is subject to include any future vector register that x86 may add.