pub unsafe extern "C" fn reg_parameter_num(reg: reg_id_t) -> c_intExpand description
Assumes that \p reg is a DR_REG_ register constant. If reg is used as part of the calling convention, returns which parameter ordinal it matches (0-based); otherwise, returns -1.