pub unsafe extern "C" fn set_x86_mode(
drcontext: *mut c_void,
x86: bool_,
) -> bool_Expand description
The decode and encode routines use a per-thread persistent flag that indicates whether to treat code as 32-bit (x86) or 64-bit (x64). This routine sets that flag to the indicated value and returns the old value. Be sure to restore the old value prior to any further application execution to avoid problems in mis-interpreting application code.
\note For 64-bit DR builds only.
\deprecated Replaced by dr_set_isa_mode().