#[repr(C)]pub struct _dr_config_client_t {
pub struct_size: usize,
pub id: client_id_t,
pub priority: usize,
pub path: *mut c_char,
pub options: *mut c_char,
pub is_alt_bitwidth: bool_,
}Expand description
Information about a client library setup.
Fields
struct_size: usizeThe size of this structure. This field must be set when passing as an input to functions like dr_get_client_info_ex(). Used for backward compatibility.
id: client_id_tThis is a client_id_t uniquely identifying the client. DynamoRIO provides the client ID as a parameter to dr_client_main(). Clients use this ID to retrieve client-specific path and option information. Outside entities also identify the target of a nudge via this ID.
priority: usizeThe client number, or priority. Client registration includes a value indicating the priority of a client relative to other clients. In multi-client settings, a client’s priority influences event callback ordering. That is, higher priority clients can register their callbacks first; DynamoRIO then calls these routines last. Client priorities range consecutively from 0 to N-1, where N is the number of registered clients. Specify priority 0 to register a client with highest priority.
path: *mut c_charA NULL-terminated string specifying the full path to a valid client library. The string length cannot exceed #MAXIMUM_PATH. The client path may not include any semicolons and when combined with \p client_options may not include all three quote characters (’, “, `) simultaneously.
When querying via dr_get_client_info_ex() or dr_client_iterator_next_ex(), the caller must either set this to NULL if that data is not needed or point at a caller-allocated array of length #MAXIMUM_PATH.
options: *mut c_charA NULL-terminated string specifying options that are available to the client as arguments of dr_client_main() or via dr_get_option_array(). The string length cannot exceed #DR_MAX_OPTIONS_LENGTH. The client options may not include any semicolons and when combined with \p client_path may not include all three quote characters (’, “, `) simultaneously.
When querying via dr_get_client_info_ex() or dr_client_iterator_next_ex(), the caller must either set this to NULL if that data is not needed or point at a caller-allocated array of length #DR_MAX_OPTIONS_LENGTH.
is_alt_bitwidth: bool_Specifies whether this is a regular client registration for the target process (this field is false) or whether this is an “alternate bitwidth” registration which specifies the configuration to use if the target process creates a child process that is a different bitwidth from itself. The regular client must first be registered on its own before the alternate client is registered, and the alternate must have the same client ID. If the target process creates a child application of a different bitwdith (e.g., the target process is 64-bit and it creates a 32-bit child), this registration allows a client of the appropriate bitwidth to be loaded into the child. Unregistering a client with dr_unregister_client() will also unregister the alternate bitwidth client with the same client ID.