#[repr(C)]pub struct _emulated_instr_t {
pub size: usize,
pub pc: app_pc,
pub instr: *mut instr_t,
pub flags: dr_emulate_options_t,
}Expand description
Holds data about an emulated instruction, typically populated by an emulation client and read by an observational client.
\note The emulated \p instr is part of the label represented by \p emulated_instr_t and as such it will be freed when the label created by drmgr_insert_emulation_start() is freed.
Fields
size: usize< Size of this struct, used for API compatibility checks.
pc: app_pc< The PC address of the emulated instruction.
instr: *mut instr_t< The emulated instruction. See Note above.
flags: dr_emulate_options_t< Flags further describing the emulation.