#[repr(C)]pub struct _tracedump_trace_header_t {
pub frag_id: c_int,
pub tag: app_pc,
pub cache_start_pc: app_pc,
pub entry_offs: c_int,
pub num_exits: c_int,
pub code_size: c_int,
pub num_bbs: uint,
pub x64: bool_,
}Expand description
Header for an individual trace in a binary trace dump file.
Fields
frag_id: c_int< Identifier for the trace.
tag: app_pc< Application address for start of trace.
cache_start_pc: app_pc< Code cache address of start of trace.
entry_offs: c_int< Offset into trace of normal entry.
num_exits: c_int< Number of exits from the trace.
code_size: c_int< Length of the trace in the code cache.
num_bbs: uint< Number of constituent basic blocks making up the trace.
x64: bool_< Whether the trace contains 64-bit code.