pub type drext_status_t = c_int;Expand description
Indicates the status of an extension API call. For more details, see the documentation for the specific API call. Indicates the status of an extension API call. For more details, see the documentation for the specific API call.