pub type tracedump_trace_header_t = _tracedump_trace_header_t;Expand description
Header for an individual trace in a binary trace dump file.
Aliased Type
#[repr(C)]pub struct tracedump_trace_header_t {
pub frag_id: i32,
pub tag: *mut u8,
pub cache_start_pc: *mut u8,
pub entry_offs: i32,
pub num_exits: i32,
pub code_size: i32,
pub num_bbs: u32,
pub x64: i8,
}Fields
frag_id: i32< Identifier for the trace.
tag: *mut u8< Application address for start of trace.
cache_start_pc: *mut u8< Code cache address of start of trace.
entry_offs: i32< Offset into trace of normal entry.
num_exits: i32< Number of exits from the trace.
code_size: i32< Length of the trace in the code cache.
num_bbs: u32< Number of constituent basic blocks making up the trace.
x64: i8< Whether the trace contains 64-bit code.